-- The conf3 of Convolutional Deep Learning on FPGA
-- by Toshio Iwata at digitalfilter.com 2022/01/02

library ieee ;
use ieee.std_logic_1164.all ;
use ieee.std_logic_arith.all ;
use ieee.std_logic_signed.all;

-------------------------------------------------------------------------------
-- Entity
-------------------------------------------------------------------------------
entity conv_conf3 is
port(
  CLK : in std_logic;                            -- clock (100MHz)
  RST_N : in std_logic;                          -- reset (active low)
  OutChSel : in std_logic_vector(7 downto 0);
  CO300 : in std_logic_vector(8 downto 0);
  CO9 : in std_logic_vector(3 downto 0);
  CO512 : in std_logic_vector(9 downto 0);
  CO512_dly2 : in std_logic_vector(9 downto 0);
  X_RD_DATA : in std_logic_vector(4095 downto 0); 
  ReluAll : out std_logic_vector(1637 downto 0); 
  ReluAllWrN : out std_logic; 
  ReluSum : out std_logic_vector(11 downto 0) ); 
end conv_conf3;

-------------------------------------------------------------------------------
-- Architecture
-------------------------------------------------------------------------------
architecture RTL of conv_conf3 is

component dotpro_conf3
   Port (
  CLK : in std_logic;                            -- clock (100MHz)
  RST_N : in std_logic;                          -- reset (active low)
  PixRomData : in std_logic_vector(7 downto 0);
  MatRomData : in std_logic_vector(2 downto 0);
  CO9is1 : in std_logic;
  CO512is0 : in std_logic;
  MATMULOUT : Out std_logic_vector(17 downto 0) );
end component;

component ROM_CW3
Port (
          CLK : In std_logic;
          ADDR : In std_logic_vector(12 downto 0);
          DATA : Out std_logic_vector(377 downto 0) );
end component;

-------------------------------------------------------------------------------
-- Signal
-------------------------------------------------------------------------------
signal CO9_clr : std_logic;
signal W3BUSY, W3BUSY_dly1, W3BUSY_dly2, W3BUSY_dly3, W3BUSY_dly4 : std_logic;

--signal mac_000 : std_logic_vector(16 downto 0);
--signal mac_001 : std_logic_vector(16 downto 0);
signal mac_000 : std_logic_vector(17 downto 0);
signal mac_001 : std_logic_vector(17 downto 0);

--signal truncate_000 : std_logic_vector(9 downto 0);
--signal truncate_001 : std_logic_vector(9 downto 0);
signal truncate_000 : std_logic_vector(13 downto 0);
signal truncate_001 : std_logic_vector(13 downto 0);

--signal Relu_000 : std_logic_vector(8 downto 0);
--signal Relu_001 : std_logic_vector(8 downto 0);
signal Relu_000 : std_logic_vector(12 downto 0);
signal Relu_001 : std_logic_vector(12 downto 0);

signal PixRomData : std_logic_vector(7 downto 0);
signal CW3Addr, CW3Addr_prev : std_logic_vector(12 downto 0);
signal CW3Addr_L : std_logic_vector(3 downto 0);
signal CW3Addr_H : std_logic_vector(12 downto 0);
signal CW3Sel : std_logic_vector(7 downto 0);
signal OutChSel_dly1, OutChSel_dly2 : std_logic_vector(7 downto 0);

signal reg_000_000, reg_000_001, reg_000_002, reg_000_003, reg_000_004, reg_000_005, reg_000_006, reg_000_007, reg_000_008, reg_000_009 : std_logic_vector(12 downto 0);
signal reg_000_010, reg_000_011, reg_000_012, reg_000_013, reg_000_014, reg_000_015, reg_000_016, reg_000_017, reg_000_018, reg_000_019 : std_logic_vector(12 downto 0);
signal reg_000_020, reg_000_021, reg_000_022, reg_000_023, reg_000_024, reg_000_025, reg_000_026, reg_000_027, reg_000_028, reg_000_029 : std_logic_vector(12 downto 0);
signal reg_000_030, reg_000_031, reg_000_032, reg_000_033, reg_000_034, reg_000_035, reg_000_036, reg_000_037, reg_000_038, reg_000_039 : std_logic_vector(12 downto 0);
signal reg_000_040, reg_000_041, reg_000_042, reg_000_043, reg_000_044, reg_000_045, reg_000_046, reg_000_047, reg_000_048, reg_000_049 : std_logic_vector(12 downto 0);
signal reg_000_050, reg_000_051, reg_000_052, reg_000_053, reg_000_054, reg_000_055, reg_000_056, reg_000_057, reg_000_058, reg_000_059 : std_logic_vector(12 downto 0);
signal reg_000_060, reg_000_061, reg_000_062, reg_000_063, reg_000_064, reg_000_065, reg_000_066, reg_000_067, reg_000_068, reg_000_069 : std_logic_vector(12 downto 0);

signal reg_001_000, reg_001_001, reg_001_002, reg_001_003, reg_001_004, reg_001_005, reg_001_006, reg_001_007, reg_001_008, reg_001_009 : std_logic_vector(12 downto 0);
signal reg_001_010, reg_001_011, reg_001_012, reg_001_013, reg_001_014, reg_001_015, reg_001_016, reg_001_017, reg_001_018, reg_001_019 : std_logic_vector(12 downto 0);
signal reg_001_020, reg_001_021, reg_001_022, reg_001_023, reg_001_024, reg_001_025, reg_001_026, reg_001_027, reg_001_028, reg_001_029 : std_logic_vector(12 downto 0);
signal reg_001_030, reg_001_031, reg_001_032, reg_001_033, reg_001_034, reg_001_035, reg_001_036, reg_001_037, reg_001_038, reg_001_039 : std_logic_vector(12 downto 0);
signal reg_001_040, reg_001_041, reg_001_042, reg_001_043, reg_001_044, reg_001_045, reg_001_046, reg_001_047, reg_001_048, reg_001_049 : std_logic_vector(12 downto 0);
signal reg_001_050, reg_001_051, reg_001_052, reg_001_053, reg_001_054, reg_001_055, reg_001_056, reg_001_057, reg_001_058, reg_001_059 : std_logic_vector(12 downto 0);
signal reg_001_060, reg_001_061, reg_001_062, reg_001_063, reg_001_064, reg_001_065, reg_001_066, reg_001_067, reg_001_068, reg_001_069 : std_logic_vector(12 downto 0);



--signal reg_000_070, reg_000_071, reg_000_072, reg_000_073, reg_000_074, reg_000_075, reg_000_076, reg_000_077, reg_000_078, reg_000_079 : std_logic_vector(7 downto 0);
--signal reg_000_080, reg_000_081, reg_000_082, reg_000_083, reg_000_084, reg_000_085, reg_000_086, reg_000_087, reg_000_088, reg_000_089 : std_logic_vector(7 downto 0);
--signal reg_000_090, reg_000_091, reg_000_092, reg_000_093, reg_000_094, reg_000_095, reg_000_096, reg_000_097, reg_000_098, reg_000_099 : std_logic_vector(7 downto 0);
--signal reg_000_100, reg_000_101, reg_000_102, reg_000_103, reg_000_104, reg_000_105, reg_000_106, reg_000_107, reg_000_108, reg_000_109 : std_logic_vector(7 downto 0);
--signal reg_000_110, reg_000_111, reg_000_112, reg_000_113, reg_000_114, reg_000_115, reg_000_116, reg_000_117, reg_000_118, reg_000_119 : std_logic_vector(7 downto 0);
--signal reg_000_120, reg_000_121, reg_000_122, reg_000_123, reg_000_124, reg_000_125, reg_000_126, reg_000_127, reg_000_128, reg_000_129 : std_logic_vector(7 downto 0);
--signal reg_000_130, reg_000_131, reg_000_132, reg_000_133, reg_000_134, reg_000_135, reg_000_136, reg_000_137, reg_000_138, reg_000_139 : std_logic_vector(7 downto 0);
--signal reg_000_140, reg_000_141, reg_000_142, reg_000_143, reg_000_144, reg_000_145, reg_000_146, reg_000_147, reg_000_148, reg_000_149 : std_logic_vector(7 downto 0);
--signal reg_000_150, reg_000_151, reg_000_152, reg_000_153, reg_000_154, reg_000_155, reg_000_156, reg_000_157, reg_000_158, reg_000_159 : std_logic_vector(7 downto 0);
--signal reg_000_160, reg_000_161, reg_000_162, reg_000_163, reg_000_164, reg_000_165, reg_000_166, reg_000_167, reg_000_168, reg_000_169 : std_logic_vector(7 downto 0);
--signal reg_000_170, reg_000_171, reg_000_172, reg_000_173, reg_000_174, reg_000_175, reg_000_176, reg_000_177, reg_000_178, reg_000_179 : std_logic_vector(7 downto 0);
--signal reg_000_180, reg_000_181, reg_000_182, reg_000_183, reg_000_184, reg_000_185, reg_000_186, reg_000_187, reg_000_188, reg_000_189 : std_logic_vector(7 downto 0);
--signal reg_000_190, reg_000_191, reg_000_192, reg_000_193, reg_000_194, reg_000_195, reg_000_196, reg_000_197, reg_000_198, reg_000_199 : std_logic_vector(7 downto 0);
--signal reg_000_200, reg_000_201, reg_000_202, reg_000_203, reg_000_204, reg_000_205, reg_000_206, reg_000_207, reg_000_208, reg_000_209 : std_logic_vector(7 downto 0);
--signal reg_000_210, reg_000_211, reg_000_212, reg_000_213, reg_000_214, reg_000_215, reg_000_216, reg_000_217, reg_000_218, reg_000_219 : std_logic_vector(7 downto 0);
--signal reg_000_220, reg_000_221, reg_000_222, reg_000_223, reg_000_224, reg_000_225, reg_000_226, reg_000_227, reg_000_228, reg_000_229 : std_logic_vector(7 downto 0);
--signal reg_000_230, reg_000_231, reg_000_232, reg_000_233, reg_000_234, reg_000_235, reg_000_236, reg_000_237, reg_000_238, reg_000_239 : std_logic_vector(7 downto 0);
--signal reg_000_240, reg_000_241, reg_000_242, reg_000_243, reg_000_244, reg_000_245, reg_000_246, reg_000_247, reg_000_248, reg_000_249 : std_logic_vector(7 downto 0);
--signal reg_000_250, reg_000_251, reg_000_252, reg_000_253, reg_000_254, reg_000_255 : std_logic_vector(7 downto 0);

signal enb_000, enb_001, enb_002, enb_003, enb_004, enb_005, enb_006, enb_007, enb_008, enb_009 : std_logic;
signal enb_010, enb_011, enb_012, enb_013, enb_014, enb_015, enb_016, enb_017, enb_018, enb_019 : std_logic;
signal enb_020, enb_021, enb_022, enb_023, enb_024, enb_025, enb_026, enb_027, enb_028, enb_029 : std_logic;
signal enb_030, enb_031, enb_032, enb_033, enb_034, enb_035, enb_036, enb_037, enb_038, enb_039 : std_logic;
signal enb_040, enb_041, enb_042, enb_043, enb_044, enb_045, enb_046, enb_047, enb_048, enb_049 : std_logic;
signal enb_050, enb_051, enb_052, enb_053, enb_054, enb_055, enb_056, enb_057, enb_058, enb_059 : std_logic;
signal enb_060, enb_061, enb_062, enb_063, enb_064, enb_065, enb_066, enb_067, enb_068, enb_069 : std_logic;
--signal enb_070, enb_071, enb_072, enb_073, enb_074, enb_075, enb_076, enb_077, enb_078, enb_079 : std_logic;
--signal enb_080, enb_081, enb_082, enb_083, enb_084, enb_085, enb_086, enb_087, enb_088, enb_089 : std_logic;
--signal enb_090, enb_091, enb_092, enb_093, enb_094, enb_095, enb_096, enb_097, enb_098, enb_099 : std_logic;
--signal enb_100, enb_101, enb_102, enb_103, enb_104, enb_105, enb_106, enb_107, enb_108, enb_109 : std_logic;
--signal enb_110, enb_111, enb_112, enb_113, enb_114, enb_115, enb_116, enb_117, enb_118, enb_119 : std_logic;
--signal enb_120, enb_121, enb_122, enb_123, enb_124, enb_125, enb_126, enb_127, enb_128, enb_129 : std_logic;
--signal enb_130, enb_131, enb_132, enb_133, enb_134, enb_135, enb_136, enb_137, enb_138, enb_139 : std_logic;
--signal enb_140, enb_141, enb_142, enb_143, enb_144, enb_145, enb_146, enb_147, enb_148, enb_149 : std_logic;
--signal enb_150, enb_151, enb_152, enb_153, enb_154, enb_155, enb_156, enb_157, enb_158, enb_159 : std_logic;
--signal enb_160, enb_161, enb_162, enb_163, enb_164, enb_165, enb_166, enb_167, enb_168, enb_169 : std_logic;
--signal enb_170, enb_171, enb_172, enb_173, enb_174, enb_175, enb_176, enb_177, enb_178, enb_179 : std_logic;
--signal enb_180, enb_181, enb_182, enb_183, enb_184, enb_185, enb_186, enb_187, enb_188, enb_189 : std_logic;
--signal enb_190, enb_191, enb_192, enb_193, enb_194, enb_195, enb_196, enb_197, enb_198, enb_199 : std_logic;
--signal enb_200, enb_201, enb_202, enb_203, enb_204, enb_205, enb_206, enb_207, enb_208, enb_209 : std_logic;
--signal enb_210, enb_211, enb_212, enb_213, enb_214, enb_215, enb_216, enb_217, enb_218, enb_219 : std_logic;
--signal enb_220, enb_221, enb_222, enb_223, enb_224, enb_225, enb_226, enb_227, enb_228, enb_229 : std_logic;
--signal enb_230, enb_231, enb_232, enb_233, enb_234, enb_235, enb_236, enb_237, enb_238, enb_239 : std_logic;
--signal enb_240, enb_241, enb_242, enb_243, enb_244, enb_245, enb_246, enb_247, enb_248, enb_249 : std_logic;
--signal enb_250, enb_251, enb_252, enb_253, enb_254, enb_255 : std_logic;
signal CO9is1, CO512is0 : std_logic;
signal CW3Data : std_logic_vector(377 downto 0);
signal coeff_000: std_logic_vector(2 downto 0);
signal coeff_001: std_logic_vector(2 downto 0);

begin

CO9is1 <= '1' when CO9 = 1 else '0'; 
CO512is0 <= '1' when CO512 = 0 else '0'; 

---------------------------------------------------------
process( RST_N, CLK )  
begin 
	if( RST_N = '0' ) then
		OutChSel_dly2 <= (others => '0');
		OutChSel_dly1 <= (others => '0');
	elsif( CLK'event and CLK = '1' ) then
		OutChSel_dly2 <= OutChSel_dly1;
		OutChSel_dly1 <= OutChSel;
	end if;  
end process;

CW3Sel <= "00" & OutChSel_dly2(5 downto 0);

---------------------------------------------------------
  PixRomData <= 
X_RD_DATA( 4095 downto 4088 ) when CO512_dly2 = "0000000000" else 
X_RD_DATA( 4087 downto 4080 ) when CO512_dly2 = "0000000001" else 
X_RD_DATA( 4079 downto 4072 ) when CO512_dly2 = "0000000010" else 
X_RD_DATA( 4071 downto 4064 ) when CO512_dly2 = "0000000011" else 
X_RD_DATA( 4063 downto 4056 ) when CO512_dly2 = "0000000100" else 
X_RD_DATA( 4055 downto 4048 ) when CO512_dly2 = "0000000101" else 
X_RD_DATA( 4047 downto 4040 ) when CO512_dly2 = "0000000110" else 
X_RD_DATA( 4039 downto 4032 ) when CO512_dly2 = "0000000111" else 
X_RD_DATA( 4031 downto 4024 ) when CO512_dly2 = "0000001000" else 
X_RD_DATA( 4023 downto 4016 ) when CO512_dly2 = "0000001001" else 
X_RD_DATA( 4015 downto 4008 ) when CO512_dly2 = "0000001010" else 
X_RD_DATA( 4007 downto 4000 ) when CO512_dly2 = "0000001011" else 
X_RD_DATA( 3999 downto 3992 ) when CO512_dly2 = "0000001100" else 
X_RD_DATA( 3991 downto 3984 ) when CO512_dly2 = "0000001101" else 
X_RD_DATA( 3983 downto 3976 ) when CO512_dly2 = "0000001110" else 
X_RD_DATA( 3975 downto 3968 ) when CO512_dly2 = "0000001111" else 
X_RD_DATA( 3967 downto 3960 ) when CO512_dly2 = "0000010000" else 
X_RD_DATA( 3959 downto 3952 ) when CO512_dly2 = "0000010001" else 
X_RD_DATA( 3951 downto 3944 ) when CO512_dly2 = "0000010010" else 
X_RD_DATA( 3943 downto 3936 ) when CO512_dly2 = "0000010011" else 
X_RD_DATA( 3935 downto 3928 ) when CO512_dly2 = "0000010100" else 
X_RD_DATA( 3927 downto 3920 ) when CO512_dly2 = "0000010101" else 
X_RD_DATA( 3919 downto 3912 ) when CO512_dly2 = "0000010110" else 
X_RD_DATA( 3911 downto 3904 ) when CO512_dly2 = "0000010111" else 
X_RD_DATA( 3903 downto 3896 ) when CO512_dly2 = "0000011000" else 
X_RD_DATA( 3895 downto 3888 ) when CO512_dly2 = "0000011001" else 
X_RD_DATA( 3887 downto 3880 ) when CO512_dly2 = "0000011010" else 
X_RD_DATA( 3879 downto 3872 ) when CO512_dly2 = "0000011011" else 
X_RD_DATA( 3871 downto 3864 ) when CO512_dly2 = "0000011100" else 
X_RD_DATA( 3863 downto 3856 ) when CO512_dly2 = "0000011101" else 
X_RD_DATA( 3855 downto 3848 ) when CO512_dly2 = "0000011110" else 
X_RD_DATA( 3847 downto 3840 ) when CO512_dly2 = "0000011111" else 
X_RD_DATA( 3839 downto 3832 ) when CO512_dly2 = "0000100000" else 
X_RD_DATA( 3831 downto 3824 ) when CO512_dly2 = "0000100001" else 
X_RD_DATA( 3823 downto 3816 ) when CO512_dly2 = "0000100010" else 
X_RD_DATA( 3815 downto 3808 ) when CO512_dly2 = "0000100011" else 
X_RD_DATA( 3807 downto 3800 ) when CO512_dly2 = "0000100100" else 
X_RD_DATA( 3799 downto 3792 ) when CO512_dly2 = "0000100101" else 
X_RD_DATA( 3791 downto 3784 ) when CO512_dly2 = "0000100110" else 
X_RD_DATA( 3783 downto 3776 ) when CO512_dly2 = "0000100111" else 
X_RD_DATA( 3775 downto 3768 ) when CO512_dly2 = "0000101000" else 
X_RD_DATA( 3767 downto 3760 ) when CO512_dly2 = "0000101001" else 
X_RD_DATA( 3759 downto 3752 ) when CO512_dly2 = "0000101010" else 
X_RD_DATA( 3751 downto 3744 ) when CO512_dly2 = "0000101011" else 
X_RD_DATA( 3743 downto 3736 ) when CO512_dly2 = "0000101100" else 
X_RD_DATA( 3735 downto 3728 ) when CO512_dly2 = "0000101101" else 
X_RD_DATA( 3727 downto 3720 ) when CO512_dly2 = "0000101110" else 
X_RD_DATA( 3719 downto 3712 ) when CO512_dly2 = "0000101111" else 
X_RD_DATA( 3711 downto 3704 ) when CO512_dly2 = "0000110000" else 
X_RD_DATA( 3703 downto 3696 ) when CO512_dly2 = "0000110001" else 
X_RD_DATA( 3695 downto 3688 ) when CO512_dly2 = "0000110010" else 
X_RD_DATA( 3687 downto 3680 ) when CO512_dly2 = "0000110011" else 
X_RD_DATA( 3679 downto 3672 ) when CO512_dly2 = "0000110100" else 
X_RD_DATA( 3671 downto 3664 ) when CO512_dly2 = "0000110101" else 
X_RD_DATA( 3663 downto 3656 ) when CO512_dly2 = "0000110110" else 
X_RD_DATA( 3655 downto 3648 ) when CO512_dly2 = "0000110111" else 
X_RD_DATA( 3647 downto 3640 ) when CO512_dly2 = "0000111000" else 
X_RD_DATA( 3639 downto 3632 ) when CO512_dly2 = "0000111001" else 
X_RD_DATA( 3631 downto 3624 ) when CO512_dly2 = "0000111010" else 
X_RD_DATA( 3623 downto 3616 ) when CO512_dly2 = "0000111011" else 
X_RD_DATA( 3615 downto 3608 ) when CO512_dly2 = "0000111100" else 
X_RD_DATA( 3607 downto 3600 ) when CO512_dly2 = "0000111101" else 
X_RD_DATA( 3599 downto 3592 ) when CO512_dly2 = "0000111110" else 
X_RD_DATA( 3591 downto 3584 ) when CO512_dly2 = "0000111111" else 
X_RD_DATA( 3583 downto 3576 ) when CO512_dly2 = "0001000000" else 
X_RD_DATA( 3575 downto 3568 ) when CO512_dly2 = "0001000001" else 
X_RD_DATA( 3567 downto 3560 ) when CO512_dly2 = "0001000010" else 
X_RD_DATA( 3559 downto 3552 ) when CO512_dly2 = "0001000011" else 
X_RD_DATA( 3551 downto 3544 ) when CO512_dly2 = "0001000100" else 
X_RD_DATA( 3543 downto 3536 ) when CO512_dly2 = "0001000101" else 
X_RD_DATA( 3535 downto 3528 ) when CO512_dly2 = "0001000110" else 
X_RD_DATA( 3527 downto 3520 ) when CO512_dly2 = "0001000111" else 
X_RD_DATA( 3519 downto 3512 ) when CO512_dly2 = "0001001000" else 
X_RD_DATA( 3511 downto 3504 ) when CO512_dly2 = "0001001001" else 
X_RD_DATA( 3503 downto 3496 ) when CO512_dly2 = "0001001010" else 
X_RD_DATA( 3495 downto 3488 ) when CO512_dly2 = "0001001011" else 
X_RD_DATA( 3487 downto 3480 ) when CO512_dly2 = "0001001100" else 
X_RD_DATA( 3479 downto 3472 ) when CO512_dly2 = "0001001101" else 
X_RD_DATA( 3471 downto 3464 ) when CO512_dly2 = "0001001110" else 
X_RD_DATA( 3463 downto 3456 ) when CO512_dly2 = "0001001111" else 
X_RD_DATA( 3455 downto 3448 ) when CO512_dly2 = "0001010000" else 
X_RD_DATA( 3447 downto 3440 ) when CO512_dly2 = "0001010001" else 
X_RD_DATA( 3439 downto 3432 ) when CO512_dly2 = "0001010010" else 
X_RD_DATA( 3431 downto 3424 ) when CO512_dly2 = "0001010011" else 
X_RD_DATA( 3423 downto 3416 ) when CO512_dly2 = "0001010100" else 
X_RD_DATA( 3415 downto 3408 ) when CO512_dly2 = "0001010101" else 
X_RD_DATA( 3407 downto 3400 ) when CO512_dly2 = "0001010110" else 
X_RD_DATA( 3399 downto 3392 ) when CO512_dly2 = "0001010111" else 
X_RD_DATA( 3391 downto 3384 ) when CO512_dly2 = "0001011000" else 
X_RD_DATA( 3383 downto 3376 ) when CO512_dly2 = "0001011001" else 
X_RD_DATA( 3375 downto 3368 ) when CO512_dly2 = "0001011010" else 
X_RD_DATA( 3367 downto 3360 ) when CO512_dly2 = "0001011011" else 
X_RD_DATA( 3359 downto 3352 ) when CO512_dly2 = "0001011100" else 
X_RD_DATA( 3351 downto 3344 ) when CO512_dly2 = "0001011101" else 
X_RD_DATA( 3343 downto 3336 ) when CO512_dly2 = "0001011110" else 
X_RD_DATA( 3335 downto 3328 ) when CO512_dly2 = "0001011111" else 
X_RD_DATA( 3327 downto 3320 ) when CO512_dly2 = "0001100000" else 
X_RD_DATA( 3319 downto 3312 ) when CO512_dly2 = "0001100001" else 
X_RD_DATA( 3311 downto 3304 ) when CO512_dly2 = "0001100010" else 
X_RD_DATA( 3303 downto 3296 ) when CO512_dly2 = "0001100011" else 
X_RD_DATA( 3295 downto 3288 ) when CO512_dly2 = "0001100100" else 
X_RD_DATA( 3287 downto 3280 ) when CO512_dly2 = "0001100101" else 
X_RD_DATA( 3279 downto 3272 ) when CO512_dly2 = "0001100110" else 
X_RD_DATA( 3271 downto 3264 ) when CO512_dly2 = "0001100111" else 
X_RD_DATA( 3263 downto 3256 ) when CO512_dly2 = "0001101000" else 
X_RD_DATA( 3255 downto 3248 ) when CO512_dly2 = "0001101001" else 
X_RD_DATA( 3247 downto 3240 ) when CO512_dly2 = "0001101010" else 
X_RD_DATA( 3239 downto 3232 ) when CO512_dly2 = "0001101011" else 
X_RD_DATA( 3231 downto 3224 ) when CO512_dly2 = "0001101100" else 
X_RD_DATA( 3223 downto 3216 ) when CO512_dly2 = "0001101101" else 
X_RD_DATA( 3215 downto 3208 ) when CO512_dly2 = "0001101110" else 
X_RD_DATA( 3207 downto 3200 ) when CO512_dly2 = "0001101111" else 
X_RD_DATA( 3199 downto 3192 ) when CO512_dly2 = "0001110000" else 
X_RD_DATA( 3191 downto 3184 ) when CO512_dly2 = "0001110001" else 
X_RD_DATA( 3183 downto 3176 ) when CO512_dly2 = "0001110010" else 
X_RD_DATA( 3175 downto 3168 ) when CO512_dly2 = "0001110011" else 
X_RD_DATA( 3167 downto 3160 ) when CO512_dly2 = "0001110100" else 
X_RD_DATA( 3159 downto 3152 ) when CO512_dly2 = "0001110101" else 
X_RD_DATA( 3151 downto 3144 ) when CO512_dly2 = "0001110110" else 
X_RD_DATA( 3143 downto 3136 ) when CO512_dly2 = "0001110111" else 
X_RD_DATA( 3135 downto 3128 ) when CO512_dly2 = "0001111000" else 
X_RD_DATA( 3127 downto 3120 ) when CO512_dly2 = "0001111001" else 
X_RD_DATA( 3119 downto 3112 ) when CO512_dly2 = "0001111010" else 
X_RD_DATA( 3111 downto 3104 ) when CO512_dly2 = "0001111011" else 
X_RD_DATA( 3103 downto 3096 ) when CO512_dly2 = "0001111100" else 
X_RD_DATA( 3095 downto 3088 ) when CO512_dly2 = "0001111101" else 
X_RD_DATA( 3087 downto 3080 ) when CO512_dly2 = "0001111110" else 
X_RD_DATA( 3079 downto 3072 ) when CO512_dly2 = "0001111111" else 
X_RD_DATA( 3071 downto 3064 ) when CO512_dly2 = "0010000000" else 
X_RD_DATA( 3063 downto 3056 ) when CO512_dly2 = "0010000001" else 
X_RD_DATA( 3055 downto 3048 ) when CO512_dly2 = "0010000010" else 
X_RD_DATA( 3047 downto 3040 ) when CO512_dly2 = "0010000011" else 
X_RD_DATA( 3039 downto 3032 ) when CO512_dly2 = "0010000100" else 
X_RD_DATA( 3031 downto 3024 ) when CO512_dly2 = "0010000101" else 
X_RD_DATA( 3023 downto 3016 ) when CO512_dly2 = "0010000110" else 
X_RD_DATA( 3015 downto 3008 ) when CO512_dly2 = "0010000111" else 
X_RD_DATA( 3007 downto 3000 ) when CO512_dly2 = "0010001000" else 
X_RD_DATA( 2999 downto 2992 ) when CO512_dly2 = "0010001001" else 
X_RD_DATA( 2991 downto 2984 ) when CO512_dly2 = "0010001010" else 
X_RD_DATA( 2983 downto 2976 ) when CO512_dly2 = "0010001011" else 
X_RD_DATA( 2975 downto 2968 ) when CO512_dly2 = "0010001100" else 
X_RD_DATA( 2967 downto 2960 ) when CO512_dly2 = "0010001101" else 
X_RD_DATA( 2959 downto 2952 ) when CO512_dly2 = "0010001110" else 
X_RD_DATA( 2951 downto 2944 ) when CO512_dly2 = "0010001111" else 
X_RD_DATA( 2943 downto 2936 ) when CO512_dly2 = "0010010000" else 
X_RD_DATA( 2935 downto 2928 ) when CO512_dly2 = "0010010001" else 
X_RD_DATA( 2927 downto 2920 ) when CO512_dly2 = "0010010010" else 
X_RD_DATA( 2919 downto 2912 ) when CO512_dly2 = "0010010011" else 
X_RD_DATA( 2911 downto 2904 ) when CO512_dly2 = "0010010100" else 
X_RD_DATA( 2903 downto 2896 ) when CO512_dly2 = "0010010101" else 
X_RD_DATA( 2895 downto 2888 ) when CO512_dly2 = "0010010110" else 
X_RD_DATA( 2887 downto 2880 ) when CO512_dly2 = "0010010111" else 
X_RD_DATA( 2879 downto 2872 ) when CO512_dly2 = "0010011000" else 
X_RD_DATA( 2871 downto 2864 ) when CO512_dly2 = "0010011001" else 
X_RD_DATA( 2863 downto 2856 ) when CO512_dly2 = "0010011010" else 
X_RD_DATA( 2855 downto 2848 ) when CO512_dly2 = "0010011011" else 
X_RD_DATA( 2847 downto 2840 ) when CO512_dly2 = "0010011100" else 
X_RD_DATA( 2839 downto 2832 ) when CO512_dly2 = "0010011101" else 
X_RD_DATA( 2831 downto 2824 ) when CO512_dly2 = "0010011110" else 
X_RD_DATA( 2823 downto 2816 ) when CO512_dly2 = "0010011111" else 
X_RD_DATA( 2815 downto 2808 ) when CO512_dly2 = "0010100000" else 
X_RD_DATA( 2807 downto 2800 ) when CO512_dly2 = "0010100001" else 
X_RD_DATA( 2799 downto 2792 ) when CO512_dly2 = "0010100010" else 
X_RD_DATA( 2791 downto 2784 ) when CO512_dly2 = "0010100011" else 
X_RD_DATA( 2783 downto 2776 ) when CO512_dly2 = "0010100100" else 
X_RD_DATA( 2775 downto 2768 ) when CO512_dly2 = "0010100101" else 
X_RD_DATA( 2767 downto 2760 ) when CO512_dly2 = "0010100110" else 
X_RD_DATA( 2759 downto 2752 ) when CO512_dly2 = "0010100111" else 
X_RD_DATA( 2751 downto 2744 ) when CO512_dly2 = "0010101000" else 
X_RD_DATA( 2743 downto 2736 ) when CO512_dly2 = "0010101001" else 
X_RD_DATA( 2735 downto 2728 ) when CO512_dly2 = "0010101010" else 
X_RD_DATA( 2727 downto 2720 ) when CO512_dly2 = "0010101011" else 
X_RD_DATA( 2719 downto 2712 ) when CO512_dly2 = "0010101100" else 
X_RD_DATA( 2711 downto 2704 ) when CO512_dly2 = "0010101101" else 
X_RD_DATA( 2703 downto 2696 ) when CO512_dly2 = "0010101110" else 
X_RD_DATA( 2695 downto 2688 ) when CO512_dly2 = "0010101111" else 
X_RD_DATA( 2687 downto 2680 ) when CO512_dly2 = "0010110000" else 
X_RD_DATA( 2679 downto 2672 ) when CO512_dly2 = "0010110001" else 
X_RD_DATA( 2671 downto 2664 ) when CO512_dly2 = "0010110010" else 
X_RD_DATA( 2663 downto 2656 ) when CO512_dly2 = "0010110011" else 
X_RD_DATA( 2655 downto 2648 ) when CO512_dly2 = "0010110100" else 
X_RD_DATA( 2647 downto 2640 ) when CO512_dly2 = "0010110101" else 
X_RD_DATA( 2639 downto 2632 ) when CO512_dly2 = "0010110110" else 
X_RD_DATA( 2631 downto 2624 ) when CO512_dly2 = "0010110111" else 
X_RD_DATA( 2623 downto 2616 ) when CO512_dly2 = "0010111000" else 
X_RD_DATA( 2615 downto 2608 ) when CO512_dly2 = "0010111001" else 
X_RD_DATA( 2607 downto 2600 ) when CO512_dly2 = "0010111010" else 
X_RD_DATA( 2599 downto 2592 ) when CO512_dly2 = "0010111011" else 
X_RD_DATA( 2591 downto 2584 ) when CO512_dly2 = "0010111100" else 
X_RD_DATA( 2583 downto 2576 ) when CO512_dly2 = "0010111101" else 
X_RD_DATA( 2575 downto 2568 ) when CO512_dly2 = "0010111110" else 
X_RD_DATA( 2567 downto 2560 ) when CO512_dly2 = "0010111111" else 
X_RD_DATA( 2559 downto 2552 ) when CO512_dly2 = "0011000000" else 
X_RD_DATA( 2551 downto 2544 ) when CO512_dly2 = "0011000001" else 
X_RD_DATA( 2543 downto 2536 ) when CO512_dly2 = "0011000010" else 
X_RD_DATA( 2535 downto 2528 ) when CO512_dly2 = "0011000011" else 
X_RD_DATA( 2527 downto 2520 ) when CO512_dly2 = "0011000100" else 
X_RD_DATA( 2519 downto 2512 ) when CO512_dly2 = "0011000101" else 
X_RD_DATA( 2511 downto 2504 ) when CO512_dly2 = "0011000110" else 
X_RD_DATA( 2503 downto 2496 ) when CO512_dly2 = "0011000111" else 
X_RD_DATA( 2495 downto 2488 ) when CO512_dly2 = "0011001000" else 
X_RD_DATA( 2487 downto 2480 ) when CO512_dly2 = "0011001001" else 
X_RD_DATA( 2479 downto 2472 ) when CO512_dly2 = "0011001010" else 
X_RD_DATA( 2471 downto 2464 ) when CO512_dly2 = "0011001011" else 
X_RD_DATA( 2463 downto 2456 ) when CO512_dly2 = "0011001100" else 
X_RD_DATA( 2455 downto 2448 ) when CO512_dly2 = "0011001101" else 
X_RD_DATA( 2447 downto 2440 ) when CO512_dly2 = "0011001110" else 
X_RD_DATA( 2439 downto 2432 ) when CO512_dly2 = "0011001111" else 
X_RD_DATA( 2431 downto 2424 ) when CO512_dly2 = "0011010000" else 
X_RD_DATA( 2423 downto 2416 ) when CO512_dly2 = "0011010001" else 
X_RD_DATA( 2415 downto 2408 ) when CO512_dly2 = "0011010010" else 
X_RD_DATA( 2407 downto 2400 ) when CO512_dly2 = "0011010011" else 
X_RD_DATA( 2399 downto 2392 ) when CO512_dly2 = "0011010100" else 
X_RD_DATA( 2391 downto 2384 ) when CO512_dly2 = "0011010101" else 
X_RD_DATA( 2383 downto 2376 ) when CO512_dly2 = "0011010110" else 
X_RD_DATA( 2375 downto 2368 ) when CO512_dly2 = "0011010111" else 
X_RD_DATA( 2367 downto 2360 ) when CO512_dly2 = "0011011000" else 
X_RD_DATA( 2359 downto 2352 ) when CO512_dly2 = "0011011001" else 
X_RD_DATA( 2351 downto 2344 ) when CO512_dly2 = "0011011010" else 
X_RD_DATA( 2343 downto 2336 ) when CO512_dly2 = "0011011011" else 
X_RD_DATA( 2335 downto 2328 ) when CO512_dly2 = "0011011100" else 
X_RD_DATA( 2327 downto 2320 ) when CO512_dly2 = "0011011101" else 
X_RD_DATA( 2319 downto 2312 ) when CO512_dly2 = "0011011110" else 
X_RD_DATA( 2311 downto 2304 ) when CO512_dly2 = "0011011111" else 
X_RD_DATA( 2303 downto 2296 ) when CO512_dly2 = "0011100000" else 
X_RD_DATA( 2295 downto 2288 ) when CO512_dly2 = "0011100001" else 
X_RD_DATA( 2287 downto 2280 ) when CO512_dly2 = "0011100010" else 
X_RD_DATA( 2279 downto 2272 ) when CO512_dly2 = "0011100011" else 
X_RD_DATA( 2271 downto 2264 ) when CO512_dly2 = "0011100100" else 
X_RD_DATA( 2263 downto 2256 ) when CO512_dly2 = "0011100101" else 
X_RD_DATA( 2255 downto 2248 ) when CO512_dly2 = "0011100110" else 
X_RD_DATA( 2247 downto 2240 ) when CO512_dly2 = "0011100111" else 
X_RD_DATA( 2239 downto 2232 ) when CO512_dly2 = "0011101000" else 
X_RD_DATA( 2231 downto 2224 ) when CO512_dly2 = "0011101001" else 
X_RD_DATA( 2223 downto 2216 ) when CO512_dly2 = "0011101010" else 
X_RD_DATA( 2215 downto 2208 ) when CO512_dly2 = "0011101011" else 
X_RD_DATA( 2207 downto 2200 ) when CO512_dly2 = "0011101100" else 
X_RD_DATA( 2199 downto 2192 ) when CO512_dly2 = "0011101101" else 
X_RD_DATA( 2191 downto 2184 ) when CO512_dly2 = "0011101110" else 
X_RD_DATA( 2183 downto 2176 ) when CO512_dly2 = "0011101111" else 
X_RD_DATA( 2175 downto 2168 ) when CO512_dly2 = "0011110000" else 
X_RD_DATA( 2167 downto 2160 ) when CO512_dly2 = "0011110001" else 
X_RD_DATA( 2159 downto 2152 ) when CO512_dly2 = "0011110010" else 
X_RD_DATA( 2151 downto 2144 ) when CO512_dly2 = "0011110011" else 
X_RD_DATA( 2143 downto 2136 ) when CO512_dly2 = "0011110100" else 
X_RD_DATA( 2135 downto 2128 ) when CO512_dly2 = "0011110101" else 
X_RD_DATA( 2127 downto 2120 ) when CO512_dly2 = "0011110110" else 
X_RD_DATA( 2119 downto 2112 ) when CO512_dly2 = "0011110111" else 
X_RD_DATA( 2111 downto 2104 ) when CO512_dly2 = "0011111000" else 
X_RD_DATA( 2103 downto 2096 ) when CO512_dly2 = "0011111001" else 
X_RD_DATA( 2095 downto 2088 ) when CO512_dly2 = "0011111010" else 
X_RD_DATA( 2087 downto 2080 ) when CO512_dly2 = "0011111011" else 
X_RD_DATA( 2079 downto 2072 ) when CO512_dly2 = "0011111100" else 
X_RD_DATA( 2071 downto 2064 ) when CO512_dly2 = "0011111101" else 
X_RD_DATA( 2063 downto 2056 ) when CO512_dly2 = "0011111110" else 
X_RD_DATA( 2055 downto 2048 ) when CO512_dly2 = "0011111111" else 
X_RD_DATA( 2047 downto 2040 ) when CO512_dly2 = "0100000000" else 
X_RD_DATA( 2039 downto 2032 ) when CO512_dly2 = "0100000001" else 
X_RD_DATA( 2031 downto 2024 ) when CO512_dly2 = "0100000010" else 
X_RD_DATA( 2023 downto 2016 ) when CO512_dly2 = "0100000011" else 
X_RD_DATA( 2015 downto 2008 ) when CO512_dly2 = "0100000100" else 
X_RD_DATA( 2007 downto 2000 ) when CO512_dly2 = "0100000101" else 
X_RD_DATA( 1999 downto 1992 ) when CO512_dly2 = "0100000110" else 
X_RD_DATA( 1991 downto 1984 ) when CO512_dly2 = "0100000111" else 
X_RD_DATA( 1983 downto 1976 ) when CO512_dly2 = "0100001000" else 
X_RD_DATA( 1975 downto 1968 ) when CO512_dly2 = "0100001001" else 
X_RD_DATA( 1967 downto 1960 ) when CO512_dly2 = "0100001010" else 
X_RD_DATA( 1959 downto 1952 ) when CO512_dly2 = "0100001011" else 
X_RD_DATA( 1951 downto 1944 ) when CO512_dly2 = "0100001100" else 
X_RD_DATA( 1943 downto 1936 ) when CO512_dly2 = "0100001101" else 
X_RD_DATA( 1935 downto 1928 ) when CO512_dly2 = "0100001110" else 
X_RD_DATA( 1927 downto 1920 ) when CO512_dly2 = "0100001111" else 
X_RD_DATA( 1919 downto 1912 ) when CO512_dly2 = "0100010000" else 
X_RD_DATA( 1911 downto 1904 ) when CO512_dly2 = "0100010001" else 
X_RD_DATA( 1903 downto 1896 ) when CO512_dly2 = "0100010010" else 
X_RD_DATA( 1895 downto 1888 ) when CO512_dly2 = "0100010011" else 
X_RD_DATA( 1887 downto 1880 ) when CO512_dly2 = "0100010100" else 
X_RD_DATA( 1879 downto 1872 ) when CO512_dly2 = "0100010101" else 
X_RD_DATA( 1871 downto 1864 ) when CO512_dly2 = "0100010110" else 
X_RD_DATA( 1863 downto 1856 ) when CO512_dly2 = "0100010111" else 
X_RD_DATA( 1855 downto 1848 ) when CO512_dly2 = "0100011000" else 
X_RD_DATA( 1847 downto 1840 ) when CO512_dly2 = "0100011001" else 
X_RD_DATA( 1839 downto 1832 ) when CO512_dly2 = "0100011010" else 
X_RD_DATA( 1831 downto 1824 ) when CO512_dly2 = "0100011011" else 
X_RD_DATA( 1823 downto 1816 ) when CO512_dly2 = "0100011100" else 
X_RD_DATA( 1815 downto 1808 ) when CO512_dly2 = "0100011101" else 
X_RD_DATA( 1807 downto 1800 ) when CO512_dly2 = "0100011110" else 
X_RD_DATA( 1799 downto 1792 ) when CO512_dly2 = "0100011111" else 
X_RD_DATA( 1791 downto 1784 ) when CO512_dly2 = "0100100000" else 
X_RD_DATA( 1783 downto 1776 ) when CO512_dly2 = "0100100001" else 
X_RD_DATA( 1775 downto 1768 ) when CO512_dly2 = "0100100010" else 
X_RD_DATA( 1767 downto 1760 ) when CO512_dly2 = "0100100011" else 
X_RD_DATA( 1759 downto 1752 ) when CO512_dly2 = "0100100100" else 
X_RD_DATA( 1751 downto 1744 ) when CO512_dly2 = "0100100101" else 
X_RD_DATA( 1743 downto 1736 ) when CO512_dly2 = "0100100110" else 
X_RD_DATA( 1735 downto 1728 ) when CO512_dly2 = "0100100111" else 
X_RD_DATA( 1727 downto 1720 ) when CO512_dly2 = "0100101000" else 
X_RD_DATA( 1719 downto 1712 ) when CO512_dly2 = "0100101001" else 
X_RD_DATA( 1711 downto 1704 ) when CO512_dly2 = "0100101010" else 
X_RD_DATA( 1703 downto 1696 ) when CO512_dly2 = "0100101011" else 
X_RD_DATA( 1695 downto 1688 ) when CO512_dly2 = "0100101100" else 
X_RD_DATA( 1687 downto 1680 ) when CO512_dly2 = "0100101101" else 
X_RD_DATA( 1679 downto 1672 ) when CO512_dly2 = "0100101110" else 
X_RD_DATA( 1671 downto 1664 ) when CO512_dly2 = "0100101111" else 
X_RD_DATA( 1663 downto 1656 ) when CO512_dly2 = "0100110000" else 
X_RD_DATA( 1655 downto 1648 ) when CO512_dly2 = "0100110001" else 
X_RD_DATA( 1647 downto 1640 ) when CO512_dly2 = "0100110010" else 
X_RD_DATA( 1639 downto 1632 ) when CO512_dly2 = "0100110011" else 
X_RD_DATA( 1631 downto 1624 ) when CO512_dly2 = "0100110100" else 
X_RD_DATA( 1623 downto 1616 ) when CO512_dly2 = "0100110101" else 
X_RD_DATA( 1615 downto 1608 ) when CO512_dly2 = "0100110110" else 
X_RD_DATA( 1607 downto 1600 ) when CO512_dly2 = "0100110111" else 
X_RD_DATA( 1599 downto 1592 ) when CO512_dly2 = "0100111000" else 
X_RD_DATA( 1591 downto 1584 ) when CO512_dly2 = "0100111001" else 
X_RD_DATA( 1583 downto 1576 ) when CO512_dly2 = "0100111010" else 
X_RD_DATA( 1575 downto 1568 ) when CO512_dly2 = "0100111011" else 
X_RD_DATA( 1567 downto 1560 ) when CO512_dly2 = "0100111100" else 
X_RD_DATA( 1559 downto 1552 ) when CO512_dly2 = "0100111101" else 
X_RD_DATA( 1551 downto 1544 ) when CO512_dly2 = "0100111110" else 
X_RD_DATA( 1543 downto 1536 ) when CO512_dly2 = "0100111111" else 
X_RD_DATA( 1535 downto 1528 ) when CO512_dly2 = "0101000000" else 
X_RD_DATA( 1527 downto 1520 ) when CO512_dly2 = "0101000001" else 
X_RD_DATA( 1519 downto 1512 ) when CO512_dly2 = "0101000010" else 
X_RD_DATA( 1511 downto 1504 ) when CO512_dly2 = "0101000011" else 
X_RD_DATA( 1503 downto 1496 ) when CO512_dly2 = "0101000100" else 
X_RD_DATA( 1495 downto 1488 ) when CO512_dly2 = "0101000101" else 
X_RD_DATA( 1487 downto 1480 ) when CO512_dly2 = "0101000110" else 
X_RD_DATA( 1479 downto 1472 ) when CO512_dly2 = "0101000111" else 
X_RD_DATA( 1471 downto 1464 ) when CO512_dly2 = "0101001000" else 
X_RD_DATA( 1463 downto 1456 ) when CO512_dly2 = "0101001001" else 
X_RD_DATA( 1455 downto 1448 ) when CO512_dly2 = "0101001010" else 
X_RD_DATA( 1447 downto 1440 ) when CO512_dly2 = "0101001011" else 
X_RD_DATA( 1439 downto 1432 ) when CO512_dly2 = "0101001100" else 
X_RD_DATA( 1431 downto 1424 ) when CO512_dly2 = "0101001101" else 
X_RD_DATA( 1423 downto 1416 ) when CO512_dly2 = "0101001110" else 
X_RD_DATA( 1415 downto 1408 ) when CO512_dly2 = "0101001111" else 
X_RD_DATA( 1407 downto 1400 ) when CO512_dly2 = "0101010000" else 
X_RD_DATA( 1399 downto 1392 ) when CO512_dly2 = "0101010001" else 
X_RD_DATA( 1391 downto 1384 ) when CO512_dly2 = "0101010010" else 
X_RD_DATA( 1383 downto 1376 ) when CO512_dly2 = "0101010011" else 
X_RD_DATA( 1375 downto 1368 ) when CO512_dly2 = "0101010100" else 
X_RD_DATA( 1367 downto 1360 ) when CO512_dly2 = "0101010101" else 
X_RD_DATA( 1359 downto 1352 ) when CO512_dly2 = "0101010110" else 
X_RD_DATA( 1351 downto 1344 ) when CO512_dly2 = "0101010111" else 
X_RD_DATA( 1343 downto 1336 ) when CO512_dly2 = "0101011000" else 
X_RD_DATA( 1335 downto 1328 ) when CO512_dly2 = "0101011001" else 
X_RD_DATA( 1327 downto 1320 ) when CO512_dly2 = "0101011010" else 
X_RD_DATA( 1319 downto 1312 ) when CO512_dly2 = "0101011011" else 
X_RD_DATA( 1311 downto 1304 ) when CO512_dly2 = "0101011100" else 
X_RD_DATA( 1303 downto 1296 ) when CO512_dly2 = "0101011101" else 
X_RD_DATA( 1295 downto 1288 ) when CO512_dly2 = "0101011110" else 
X_RD_DATA( 1287 downto 1280 ) when CO512_dly2 = "0101011111" else 
X_RD_DATA( 1279 downto 1272 ) when CO512_dly2 = "0101100000" else 
X_RD_DATA( 1271 downto 1264 ) when CO512_dly2 = "0101100001" else 
X_RD_DATA( 1263 downto 1256 ) when CO512_dly2 = "0101100010" else 
X_RD_DATA( 1255 downto 1248 ) when CO512_dly2 = "0101100011" else 
X_RD_DATA( 1247 downto 1240 ) when CO512_dly2 = "0101100100" else 
X_RD_DATA( 1239 downto 1232 ) when CO512_dly2 = "0101100101" else 
X_RD_DATA( 1231 downto 1224 ) when CO512_dly2 = "0101100110" else 
X_RD_DATA( 1223 downto 1216 ) when CO512_dly2 = "0101100111" else 
X_RD_DATA( 1215 downto 1208 ) when CO512_dly2 = "0101101000" else 
X_RD_DATA( 1207 downto 1200 ) when CO512_dly2 = "0101101001" else 
X_RD_DATA( 1199 downto 1192 ) when CO512_dly2 = "0101101010" else 
X_RD_DATA( 1191 downto 1184 ) when CO512_dly2 = "0101101011" else 
X_RD_DATA( 1183 downto 1176 ) when CO512_dly2 = "0101101100" else 
X_RD_DATA( 1175 downto 1168 ) when CO512_dly2 = "0101101101" else 
X_RD_DATA( 1167 downto 1160 ) when CO512_dly2 = "0101101110" else 
X_RD_DATA( 1159 downto 1152 ) when CO512_dly2 = "0101101111" else 
X_RD_DATA( 1151 downto 1144 ) when CO512_dly2 = "0101110000" else 
X_RD_DATA( 1143 downto 1136 ) when CO512_dly2 = "0101110001" else 
X_RD_DATA( 1135 downto 1128 ) when CO512_dly2 = "0101110010" else 
X_RD_DATA( 1127 downto 1120 ) when CO512_dly2 = "0101110011" else 
X_RD_DATA( 1119 downto 1112 ) when CO512_dly2 = "0101110100" else 
X_RD_DATA( 1111 downto 1104 ) when CO512_dly2 = "0101110101" else 
X_RD_DATA( 1103 downto 1096 ) when CO512_dly2 = "0101110110" else 
X_RD_DATA( 1095 downto 1088 ) when CO512_dly2 = "0101110111" else 
X_RD_DATA( 1087 downto 1080 ) when CO512_dly2 = "0101111000" else 
X_RD_DATA( 1079 downto 1072 ) when CO512_dly2 = "0101111001" else 
X_RD_DATA( 1071 downto 1064 ) when CO512_dly2 = "0101111010" else 
X_RD_DATA( 1063 downto 1056 ) when CO512_dly2 = "0101111011" else 
X_RD_DATA( 1055 downto 1048 ) when CO512_dly2 = "0101111100" else 
X_RD_DATA( 1047 downto 1040 ) when CO512_dly2 = "0101111101" else 
X_RD_DATA( 1039 downto 1032 ) when CO512_dly2 = "0101111110" else 
X_RD_DATA( 1031 downto 1024 ) when CO512_dly2 = "0101111111" else 
X_RD_DATA( 1023 downto 1016 ) when CO512_dly2 = "0110000000" else 
X_RD_DATA( 1015 downto 1008 ) when CO512_dly2 = "0110000001" else 
X_RD_DATA( 1007 downto 1000 ) when CO512_dly2 = "0110000010" else 
X_RD_DATA( 999 downto 992 ) when CO512_dly2 = "0110000011" else 
X_RD_DATA( 991 downto 984 ) when CO512_dly2 = "0110000100" else 
X_RD_DATA( 983 downto 976 ) when CO512_dly2 = "0110000101" else 
X_RD_DATA( 975 downto 968 ) when CO512_dly2 = "0110000110" else 
X_RD_DATA( 967 downto 960 ) when CO512_dly2 = "0110000111" else 
X_RD_DATA( 959 downto 952 ) when CO512_dly2 = "0110001000" else 
X_RD_DATA( 951 downto 944 ) when CO512_dly2 = "0110001001" else 
X_RD_DATA( 943 downto 936 ) when CO512_dly2 = "0110001010" else 
X_RD_DATA( 935 downto 928 ) when CO512_dly2 = "0110001011" else 
X_RD_DATA( 927 downto 920 ) when CO512_dly2 = "0110001100" else 
X_RD_DATA( 919 downto 912 ) when CO512_dly2 = "0110001101" else 
X_RD_DATA( 911 downto 904 ) when CO512_dly2 = "0110001110" else 
X_RD_DATA( 903 downto 896 ) when CO512_dly2 = "0110001111" else 
X_RD_DATA( 895 downto 888 ) when CO512_dly2 = "0110010000" else 
X_RD_DATA( 887 downto 880 ) when CO512_dly2 = "0110010001" else 
X_RD_DATA( 879 downto 872 ) when CO512_dly2 = "0110010010" else 
X_RD_DATA( 871 downto 864 ) when CO512_dly2 = "0110010011" else 
X_RD_DATA( 863 downto 856 ) when CO512_dly2 = "0110010100" else 
X_RD_DATA( 855 downto 848 ) when CO512_dly2 = "0110010101" else 
X_RD_DATA( 847 downto 840 ) when CO512_dly2 = "0110010110" else 
X_RD_DATA( 839 downto 832 ) when CO512_dly2 = "0110010111" else 
X_RD_DATA( 831 downto 824 ) when CO512_dly2 = "0110011000" else 
X_RD_DATA( 823 downto 816 ) when CO512_dly2 = "0110011001" else 
X_RD_DATA( 815 downto 808 ) when CO512_dly2 = "0110011010" else 
X_RD_DATA( 807 downto 800 ) when CO512_dly2 = "0110011011" else 
X_RD_DATA( 799 downto 792 ) when CO512_dly2 = "0110011100" else 
X_RD_DATA( 791 downto 784 ) when CO512_dly2 = "0110011101" else 
X_RD_DATA( 783 downto 776 ) when CO512_dly2 = "0110011110" else 
X_RD_DATA( 775 downto 768 ) when CO512_dly2 = "0110011111" else 
X_RD_DATA( 767 downto 760 ) when CO512_dly2 = "0110100000" else 
X_RD_DATA( 759 downto 752 ) when CO512_dly2 = "0110100001" else 
X_RD_DATA( 751 downto 744 ) when CO512_dly2 = "0110100010" else 
X_RD_DATA( 743 downto 736 ) when CO512_dly2 = "0110100011" else 
X_RD_DATA( 735 downto 728 ) when CO512_dly2 = "0110100100" else 
X_RD_DATA( 727 downto 720 ) when CO512_dly2 = "0110100101" else 
X_RD_DATA( 719 downto 712 ) when CO512_dly2 = "0110100110" else 
X_RD_DATA( 711 downto 704 ) when CO512_dly2 = "0110100111" else 
X_RD_DATA( 703 downto 696 ) when CO512_dly2 = "0110101000" else 
X_RD_DATA( 695 downto 688 ) when CO512_dly2 = "0110101001" else 
X_RD_DATA( 687 downto 680 ) when CO512_dly2 = "0110101010" else 
X_RD_DATA( 679 downto 672 ) when CO512_dly2 = "0110101011" else 
X_RD_DATA( 671 downto 664 ) when CO512_dly2 = "0110101100" else 
X_RD_DATA( 663 downto 656 ) when CO512_dly2 = "0110101101" else 
X_RD_DATA( 655 downto 648 ) when CO512_dly2 = "0110101110" else 
X_RD_DATA( 647 downto 640 ) when CO512_dly2 = "0110101111" else 
X_RD_DATA( 639 downto 632 ) when CO512_dly2 = "0110110000" else 
X_RD_DATA( 631 downto 624 ) when CO512_dly2 = "0110110001" else 
X_RD_DATA( 623 downto 616 ) when CO512_dly2 = "0110110010" else 
X_RD_DATA( 615 downto 608 ) when CO512_dly2 = "0110110011" else 
X_RD_DATA( 607 downto 600 ) when CO512_dly2 = "0110110100" else 
X_RD_DATA( 599 downto 592 ) when CO512_dly2 = "0110110101" else 
X_RD_DATA( 591 downto 584 ) when CO512_dly2 = "0110110110" else 
X_RD_DATA( 583 downto 576 ) when CO512_dly2 = "0110110111" else 
X_RD_DATA( 575 downto 568 ) when CO512_dly2 = "0110111000" else 
X_RD_DATA( 567 downto 560 ) when CO512_dly2 = "0110111001" else 
X_RD_DATA( 559 downto 552 ) when CO512_dly2 = "0110111010" else 
X_RD_DATA( 551 downto 544 ) when CO512_dly2 = "0110111011" else 
X_RD_DATA( 543 downto 536 ) when CO512_dly2 = "0110111100" else 
X_RD_DATA( 535 downto 528 ) when CO512_dly2 = "0110111101" else 
X_RD_DATA( 527 downto 520 ) when CO512_dly2 = "0110111110" else 
X_RD_DATA( 519 downto 512 ) when CO512_dly2 = "0110111111" else 
X_RD_DATA( 511 downto 504 ) when CO512_dly2 = "0111000000" else 
X_RD_DATA( 503 downto 496 ) when CO512_dly2 = "0111000001" else 
X_RD_DATA( 495 downto 488 ) when CO512_dly2 = "0111000010" else 
X_RD_DATA( 487 downto 480 ) when CO512_dly2 = "0111000011" else 
X_RD_DATA( 479 downto 472 ) when CO512_dly2 = "0111000100" else 
X_RD_DATA( 471 downto 464 ) when CO512_dly2 = "0111000101" else 
X_RD_DATA( 463 downto 456 ) when CO512_dly2 = "0111000110" else 
X_RD_DATA( 455 downto 448 ) when CO512_dly2 = "0111000111" else 
X_RD_DATA( 447 downto 440 ) when CO512_dly2 = "0111001000" else 
X_RD_DATA( 439 downto 432 ) when CO512_dly2 = "0111001001" else 
X_RD_DATA( 431 downto 424 ) when CO512_dly2 = "0111001010" else 
X_RD_DATA( 423 downto 416 ) when CO512_dly2 = "0111001011" else 
X_RD_DATA( 415 downto 408 ) when CO512_dly2 = "0111001100" else 
X_RD_DATA( 407 downto 400 ) when CO512_dly2 = "0111001101" else 
X_RD_DATA( 399 downto 392 ) when CO512_dly2 = "0111001110" else 
X_RD_DATA( 391 downto 384 ) when CO512_dly2 = "0111001111" else 
X_RD_DATA( 383 downto 376 ) when CO512_dly2 = "0111010000" else 
X_RD_DATA( 375 downto 368 ) when CO512_dly2 = "0111010001" else 
X_RD_DATA( 367 downto 360 ) when CO512_dly2 = "0111010010" else 
X_RD_DATA( 359 downto 352 ) when CO512_dly2 = "0111010011" else 
X_RD_DATA( 351 downto 344 ) when CO512_dly2 = "0111010100" else 
X_RD_DATA( 343 downto 336 ) when CO512_dly2 = "0111010101" else 
X_RD_DATA( 335 downto 328 ) when CO512_dly2 = "0111010110" else 
X_RD_DATA( 327 downto 320 ) when CO512_dly2 = "0111010111" else 
X_RD_DATA( 319 downto 312 ) when CO512_dly2 = "0111011000" else 
X_RD_DATA( 311 downto 304 ) when CO512_dly2 = "0111011001" else 
X_RD_DATA( 303 downto 296 ) when CO512_dly2 = "0111011010" else 
X_RD_DATA( 295 downto 288 ) when CO512_dly2 = "0111011011" else 
X_RD_DATA( 287 downto 280 ) when CO512_dly2 = "0111011100" else 
X_RD_DATA( 279 downto 272 ) when CO512_dly2 = "0111011101" else 
X_RD_DATA( 271 downto 264 ) when CO512_dly2 = "0111011110" else 
X_RD_DATA( 263 downto 256 ) when CO512_dly2 = "0111011111" else 
X_RD_DATA( 255 downto 248 ) when CO512_dly2 = "0111100000" else 
X_RD_DATA( 247 downto 240 ) when CO512_dly2 = "0111100001" else 
X_RD_DATA( 239 downto 232 ) when CO512_dly2 = "0111100010" else 
X_RD_DATA( 231 downto 224 ) when CO512_dly2 = "0111100011" else 
X_RD_DATA( 223 downto 216 ) when CO512_dly2 = "0111100100" else 
X_RD_DATA( 215 downto 208 ) when CO512_dly2 = "0111100101" else 
X_RD_DATA( 207 downto 200 ) when CO512_dly2 = "0111100110" else 
X_RD_DATA( 199 downto 192 ) when CO512_dly2 = "0111100111" else 
X_RD_DATA( 191 downto 184 ) when CO512_dly2 = "0111101000" else 
X_RD_DATA( 183 downto 176 ) when CO512_dly2 = "0111101001" else 
X_RD_DATA( 175 downto 168 ) when CO512_dly2 = "0111101010" else 
X_RD_DATA( 167 downto 160 ) when CO512_dly2 = "0111101011" else 
X_RD_DATA( 159 downto 152 ) when CO512_dly2 = "0111101100" else 
X_RD_DATA( 151 downto 144 ) when CO512_dly2 = "0111101101" else 
X_RD_DATA( 143 downto 136 ) when CO512_dly2 = "0111101110" else 
X_RD_DATA( 135 downto 128 ) when CO512_dly2 = "0111101111" else 
X_RD_DATA( 127 downto 120 ) when CO512_dly2 = "0111110000" else 
X_RD_DATA( 119 downto 112 ) when CO512_dly2 = "0111110001" else 
X_RD_DATA( 111 downto 104 ) when CO512_dly2 = "0111110010" else 
X_RD_DATA( 103 downto 96 ) when CO512_dly2 = "0111110011" else 
X_RD_DATA( 95 downto 88 ) when CO512_dly2 = "0111110100" else 
X_RD_DATA( 87 downto 80 ) when CO512_dly2 = "0111110101" else 
X_RD_DATA( 79 downto 72 ) when CO512_dly2 = "0111110110" else 
X_RD_DATA( 71 downto 64 ) when CO512_dly2 = "0111110111" else 
X_RD_DATA( 63 downto 56 ) when CO512_dly2 = "0111111000" else 
X_RD_DATA( 55 downto 48 ) when CO512_dly2 = "0111111001" else 
X_RD_DATA( 47 downto 40 ) when CO512_dly2 = "0111111010" else 
X_RD_DATA( 39 downto 32 ) when CO512_dly2 = "0111111011" else 
X_RD_DATA( 31 downto 24 ) when CO512_dly2 = "0111111100" else 
X_RD_DATA( 23 downto 16 ) when CO512_dly2 = "0111111101" else 
X_RD_DATA( 15 downto 8 ) when CO512_dly2 = "0111111110" else 
X_RD_DATA( 7 downto 0 ); -- when CO512_dly2 = "0111111111" else 


CW3Addr_L <= CO9;
CW3Addr_H <= (CO512(9 downto 0) & "000") + ("000" & CO512); -- CO512 x 9
CW3Addr_prev <= CW3Addr_H + ("0000000" & CW3Addr_L);

---------------------------------------------------------
process( RST_N, CLK )
begin
        if( RST_N = '0' ) then
                CW3Addr <= (others => '0');
        elsif( CLK'event and CLK = '1' ) then
                CW3Addr <= CW3Addr_prev;
        end if; 
end process;


---------------------------------------------------------
enb_000 <= '1' when CW3Sel = 1 and CO512 = 511 else '0';
enb_001 <= '1' when CW3Sel = 2 and CO512 = 511 else '0';
enb_002 <= '1' when CW3Sel = 3 and CO512 = 511 else '0';
enb_003 <= '1' when CW3Sel = 4 and CO512 = 511 else '0';
enb_004 <= '1' when CW3Sel = 5 and CO512 = 511 else '0';
enb_005 <= '1' when CW3Sel = 6 and CO512 = 511 else '0';
enb_006 <= '1' when CW3Sel = 7 and CO512 = 511 else '0';
enb_007 <= '1' when CW3Sel = 8 and CO512 = 511 else '0';
enb_008 <= '1' when CW3Sel = 9 and CO512 = 511 else '0';
enb_009 <= '1' when CW3Sel = 10 and CO512 = 511 else '0';
enb_010 <= '1' when CW3Sel = 11 and CO512 = 511 else '0';
enb_011 <= '1' when CW3Sel = 12 and CO512 = 511 else '0';
enb_012 <= '1' when CW3Sel = 13 and CO512 = 511 else '0';
enb_013 <= '1' when CW3Sel = 14 and CO512 = 511 else '0';
enb_014 <= '1' when CW3Sel = 15 and CO512 = 511 else '0';
enb_015 <= '1' when CW3Sel = 16 and CO512 = 511 else '0';
enb_016 <= '1' when CW3Sel = 17 and CO512 = 511 else '0';
enb_017 <= '1' when CW3Sel = 18 and CO512 = 511 else '0';
enb_018 <= '1' when CW3Sel = 19 and CO512 = 511 else '0';
enb_019 <= '1' when CW3Sel = 20 and CO512 = 511 else '0';
enb_020 <= '1' when CW3Sel = 21 and CO512 = 511 else '0';
enb_021 <= '1' when CW3Sel = 22 and CO512 = 511 else '0';
enb_022 <= '1' when CW3Sel = 23 and CO512 = 511 else '0';
enb_023 <= '1' when CW3Sel = 24 and CO512 = 511 else '0';
enb_024 <= '1' when CW3Sel = 25 and CO512 = 511 else '0';
enb_025 <= '1' when CW3Sel = 26 and CO512 = 511 else '0';
enb_026 <= '1' when CW3Sel = 27 and CO512 = 511 else '0';
enb_027 <= '1' when CW3Sel = 28 and CO512 = 511 else '0';
enb_028 <= '1' when CW3Sel = 29 and CO512 = 511 else '0';
enb_029 <= '1' when CW3Sel = 30 and CO512 = 511 else '0';
enb_030 <= '1' when CW3Sel = 31 and CO512 = 511 else '0';
enb_031 <= '1' when CW3Sel = 32 and CO512 = 511 else '0';
enb_032 <= '1' when CW3Sel = 33 and CO512 = 511 else '0';
enb_033 <= '1' when CW3Sel = 34 and CO512 = 511 else '0';
enb_034 <= '1' when CW3Sel = 35 and CO512 = 511 else '0';
enb_035 <= '1' when CW3Sel = 36 and CO512 = 511 else '0';
enb_036 <= '1' when CW3Sel = 37 and CO512 = 511 else '0';
enb_037 <= '1' when CW3Sel = 38 and CO512 = 511 else '0';
enb_038 <= '1' when CW3Sel = 39 and CO512 = 511 else '0';
enb_039 <= '1' when CW3Sel = 40 and CO512 = 511 else '0';
enb_040 <= '1' when CW3Sel = 41 and CO512 = 511 else '0';
enb_041 <= '1' when CW3Sel = 42 and CO512 = 511 else '0';
enb_042 <= '1' when CW3Sel = 43 and CO512 = 511 else '0';
enb_043 <= '1' when CW3Sel = 44 and CO512 = 511 else '0';
enb_044 <= '1' when CW3Sel = 45 and CO512 = 511 else '0';
enb_045 <= '1' when CW3Sel = 46 and CO512 = 511 else '0';
enb_046 <= '1' when CW3Sel = 47 and CO512 = 511 else '0';
enb_047 <= '1' when CW3Sel = 48 and CO512 = 511 else '0';
enb_048 <= '1' when CW3Sel = 49 and CO512 = 511 else '0';
enb_049 <= '1' when CW3Sel = 50 and CO512 = 511 else '0';
enb_050 <= '1' when CW3Sel = 51 and CO512 = 511 else '0';
enb_051 <= '1' when CW3Sel = 52 and CO512 = 511 else '0';
enb_052 <= '1' when CW3Sel = 53 and CO512 = 511 else '0';
enb_053 <= '1' when CW3Sel = 54 and CO512 = 511 else '0';
enb_054 <= '1' when CW3Sel = 55 and CO512 = 511 else '0';
enb_055 <= '1' when CW3Sel = 56 and CO512 = 511 else '0';
enb_056 <= '1' when CW3Sel = 57 and CO512 = 511 else '0';
enb_057 <= '1' when CW3Sel = 58 and CO512 = 511 else '0';
enb_058 <= '1' when CW3Sel = 59 and CO512 = 511 else '0';
enb_059 <= '1' when CW3Sel = 60 and CO512 = 511 else '0';
enb_060 <= '1' when CW3Sel = 61 and CO512 = 511 else '0';
enb_061 <= '1' when CW3Sel = 62 and CO512 = 511 else '0';
enb_062 <= '1' when CW3Sel = 63 and CO512 = 511 else '0';
enb_063 <= '1' when CW3Sel = 0 and CO512 = 511 else '0';

---enb_064 <= '1' when CW3Sel = 65 and CO512 = 511 else '0';
---enb_065 <= '1' when CW3Sel = 66 and CO512 = 511 else '0';
---enb_066 <= '1' when CW3Sel = 67 and CO512 = 511 else '0';
---enb_067 <= '1' when CW3Sel = 68 and CO512 = 511 else '0';
---enb_068 <= '1' when CW3Sel = 69 and CO512 = 511 else '0';
---enb_069 <= '1' when CW3Sel = 70 and CO512 = 511 else '0';
---enb_070 <= '1' when CW3Sel = 71 and CO512 = 511 else '0';
---enb_071 <= '1' when CW3Sel = 72 and CO512 = 511 else '0';
---enb_072 <= '1' when CW3Sel = 73 and CO512 = 511 else '0';
---enb_073 <= '1' when CW3Sel = 74 and CO512 = 511 else '0';
---enb_074 <= '1' when CW3Sel = 75 and CO512 = 511 else '0';
---enb_075 <= '1' when CW3Sel = 76 and CO512 = 511 else '0';
---enb_076 <= '1' when CW3Sel = 77 and CO512 = 511 else '0';
---enb_077 <= '1' when CW3Sel = 78 and CO512 = 511 else '0';
---enb_078 <= '1' when CW3Sel = 79 and CO512 = 511 else '0';
---enb_079 <= '1' when CW3Sel = 80 and CO512 = 511 else '0';
---enb_080 <= '1' when CW3Sel = 81 and CO512 = 511 else '0';
---enb_081 <= '1' when CW3Sel = 82 and CO512 = 511 else '0';
---enb_082 <= '1' when CW3Sel = 83 and CO512 = 511 else '0';
---enb_083 <= '1' when CW3Sel = 84 and CO512 = 511 else '0';
---enb_084 <= '1' when CW3Sel = 85 and CO512 = 511 else '0';
---enb_085 <= '1' when CW3Sel = 86 and CO512 = 511 else '0';
---enb_086 <= '1' when CW3Sel = 87 and CO512 = 511 else '0';
---enb_087 <= '1' when CW3Sel = 88 and CO512 = 511 else '0';
---enb_088 <= '1' when CW3Sel = 89 and CO512 = 511 else '0';
---enb_089 <= '1' when CW3Sel = 90 and CO512 = 511 else '0';
---enb_090 <= '1' when CW3Sel = 91 and CO512 = 511 else '0';
---enb_091 <= '1' when CW3Sel = 92 and CO512 = 511 else '0';
---enb_092 <= '1' when CW3Sel = 93 and CO512 = 511 else '0';
---enb_093 <= '1' when CW3Sel = 94 and CO512 = 511 else '0';
---enb_094 <= '1' when CW3Sel = 95 and CO512 = 511 else '0';
---enb_095 <= '1' when CW3Sel = 96 and CO512 = 511 else '0';
---enb_096 <= '1' when CW3Sel = 97 and CO512 = 511 else '0';
---enb_097 <= '1' when CW3Sel = 98 and CO512 = 511 else '0';
---enb_098 <= '1' when CW3Sel = 99 and CO512 = 511 else '0';
---enb_099 <= '1' when CW3Sel = 100 and CO512 = 511 else '0';
---enb_100 <= '1' when CW3Sel = 101 and CO512 = 511 else '0';
---enb_101 <= '1' when CW3Sel = 102 and CO512 = 511 else '0';
---enb_102 <= '1' when CW3Sel = 103 and CO512 = 511 else '0';
---enb_103 <= '1' when CW3Sel = 104 and CO512 = 511 else '0';
---enb_104 <= '1' when CW3Sel = 105 and CO512 = 511 else '0';
---enb_105 <= '1' when CW3Sel = 106 and CO512 = 511 else '0';
---enb_106 <= '1' when CW3Sel = 107 and CO512 = 511 else '0';
---enb_107 <= '1' when CW3Sel = 108 and CO512 = 511 else '0';
---enb_108 <= '1' when CW3Sel = 109 and CO512 = 511 else '0';
---enb_109 <= '1' when CW3Sel = 110 and CO512 = 511 else '0';
---enb_110 <= '1' when CW3Sel = 111 and CO512 = 511 else '0';
---enb_111 <= '1' when CW3Sel = 112 and CO512 = 511 else '0';
---enb_112 <= '1' when CW3Sel = 113 and CO512 = 511 else '0';
---enb_113 <= '1' when CW3Sel = 114 and CO512 = 511 else '0';
---enb_114 <= '1' when CW3Sel = 115 and CO512 = 511 else '0';
---enb_115 <= '1' when CW3Sel = 116 and CO512 = 511 else '0';
---enb_116 <= '1' when CW3Sel = 117 and CO512 = 511 else '0';
---enb_117 <= '1' when CW3Sel = 118 and CO512 = 511 else '0';
---enb_118 <= '1' when CW3Sel = 119 and CO512 = 511 else '0';
---enb_119 <= '1' when CW3Sel = 120 and CO512 = 511 else '0';
---enb_120 <= '1' when CW3Sel = 121 and CO512 = 511 else '0';
---enb_121 <= '1' when CW3Sel = 122 and CO512 = 511 else '0';
---enb_122 <= '1' when CW3Sel = 123 and CO512 = 511 else '0';
---enb_123 <= '1' when CW3Sel = 124 and CO512 = 511 else '0';
---enb_124 <= '1' when CW3Sel = 125 and CO512 = 511 else '0';
---enb_125 <= '1' when CW3Sel = 126 and CO512 = 511 else '0';
---enb_126 <= '1' when CW3Sel = 127 and CO512 = 511 else '0';
---enb_127 <= '1' when CW3Sel = 128 and CO512 = 511 else '0';
---enb_128 <= '1' when CW3Sel = 129 and CO512 = 511 else '0';
---enb_129 <= '1' when CW3Sel = 130 and CO512 = 511 else '0';
---enb_130 <= '1' when CW3Sel = 131 and CO512 = 511 else '0';
---enb_131 <= '1' when CW3Sel = 132 and CO512 = 511 else '0';
---enb_132 <= '1' when CW3Sel = 133 and CO512 = 511 else '0';
---enb_133 <= '1' when CW3Sel = 134 and CO512 = 511 else '0';
---enb_134 <= '1' when CW3Sel = 135 and CO512 = 511 else '0';
---enb_135 <= '1' when CW3Sel = 136 and CO512 = 511 else '0';
---enb_136 <= '1' when CW3Sel = 137 and CO512 = 511 else '0';
---enb_137 <= '1' when CW3Sel = 138 and CO512 = 511 else '0';
---enb_138 <= '1' when CW3Sel = 139 and CO512 = 511 else '0';
---enb_139 <= '1' when CW3Sel = 140 and CO512 = 511 else '0';
---enb_140 <= '1' when CW3Sel = 141 and CO512 = 511 else '0';
---enb_141 <= '1' when CW3Sel = 142 and CO512 = 511 else '0';
---enb_142 <= '1' when CW3Sel = 143 and CO512 = 511 else '0';
---enb_143 <= '1' when CW3Sel = 144 and CO512 = 511 else '0';
---enb_144 <= '1' when CW3Sel = 145 and CO512 = 511 else '0';
---enb_145 <= '1' when CW3Sel = 146 and CO512 = 511 else '0';
---enb_146 <= '1' when CW3Sel = 147 and CO512 = 511 else '0';
---enb_147 <= '1' when CW3Sel = 148 and CO512 = 511 else '0';
---enb_148 <= '1' when CW3Sel = 149 and CO512 = 511 else '0';
---enb_149 <= '1' when CW3Sel = 150 and CO512 = 511 else '0';
---enb_150 <= '1' when CW3Sel = 151 and CO512 = 511 else '0';
---enb_151 <= '1' when CW3Sel = 152 and CO512 = 511 else '0';
---enb_152 <= '1' when CW3Sel = 153 and CO512 = 511 else '0';
---enb_153 <= '1' when CW3Sel = 154 and CO512 = 511 else '0';
---enb_154 <= '1' when CW3Sel = 155 and CO512 = 511 else '0';
---enb_155 <= '1' when CW3Sel = 156 and CO512 = 511 else '0';
---enb_156 <= '1' when CW3Sel = 157 and CO512 = 511 else '0';
---enb_157 <= '1' when CW3Sel = 158 and CO512 = 511 else '0';
---enb_158 <= '1' when CW3Sel = 159 and CO512 = 511 else '0';
---enb_159 <= '1' when CW3Sel = 160 and CO512 = 511 else '0';
---enb_160 <= '1' when CW3Sel = 161 and CO512 = 511 else '0';
---enb_161 <= '1' when CW3Sel = 162 and CO512 = 511 else '0';
---enb_162 <= '1' when CW3Sel = 163 and CO512 = 511 else '0';
---enb_163 <= '1' when CW3Sel = 164 and CO512 = 511 else '0';
---enb_164 <= '1' when CW3Sel = 165 and CO512 = 511 else '0';
---enb_165 <= '1' when CW3Sel = 166 and CO512 = 511 else '0';
---enb_166 <= '1' when CW3Sel = 167 and CO512 = 511 else '0';
---enb_167 <= '1' when CW3Sel = 168 and CO512 = 511 else '0';
---enb_168 <= '1' when CW3Sel = 169 and CO512 = 511 else '0';
---enb_169 <= '1' when CW3Sel = 170 and CO512 = 511 else '0';
---enb_170 <= '1' when CW3Sel = 171 and CO512 = 511 else '0';
---enb_171 <= '1' when CW3Sel = 172 and CO512 = 511 else '0';
---enb_172 <= '1' when CW3Sel = 173 and CO512 = 511 else '0';
---enb_173 <= '1' when CW3Sel = 174 and CO512 = 511 else '0';
---enb_174 <= '1' when CW3Sel = 175 and CO512 = 511 else '0';
---enb_175 <= '1' when CW3Sel = 176 and CO512 = 511 else '0';
---enb_176 <= '1' when CW3Sel = 177 and CO512 = 511 else '0';
---enb_177 <= '1' when CW3Sel = 178 and CO512 = 511 else '0';
---enb_178 <= '1' when CW3Sel = 179 and CO512 = 511 else '0';
---enb_179 <= '1' when CW3Sel = 180 and CO512 = 511 else '0';
---enb_180 <= '1' when CW3Sel = 181 and CO512 = 511 else '0';
---enb_181 <= '1' when CW3Sel = 182 and CO512 = 511 else '0';
---enb_182 <= '1' when CW3Sel = 183 and CO512 = 511 else '0';
---enb_183 <= '1' when CW3Sel = 184 and CO512 = 511 else '0';
---enb_184 <= '1' when CW3Sel = 185 and CO512 = 511 else '0';
---enb_185 <= '1' when CW3Sel = 186 and CO512 = 511 else '0';
---enb_186 <= '1' when CW3Sel = 187 and CO512 = 511 else '0';
---enb_187 <= '1' when CW3Sel = 188 and CO512 = 511 else '0';
---enb_188 <= '1' when CW3Sel = 189 and CO512 = 511 else '0';
---enb_189 <= '1' when CW3Sel = 190 and CO512 = 511 else '0';
---enb_190 <= '1' when CW3Sel = 191 and CO512 = 511 else '0';
---enb_191 <= '1' when CW3Sel = 192 and CO512 = 511 else '0';
---enb_192 <= '1' when CW3Sel = 193 and CO512 = 511 else '0';
---enb_193 <= '1' when CW3Sel = 194 and CO512 = 511 else '0';
---enb_194 <= '1' when CW3Sel = 195 and CO512 = 511 else '0';
---enb_195 <= '1' when CW3Sel = 196 and CO512 = 511 else '0';
---enb_196 <= '1' when CW3Sel = 197 and CO512 = 511 else '0';
---enb_197 <= '1' when CW3Sel = 198 and CO512 = 511 else '0';
---enb_198 <= '1' when CW3Sel = 199 and CO512 = 511 else '0';
---enb_199 <= '1' when CW3Sel = 200 and CO512 = 511 else '0';
---enb_200 <= '1' when CW3Sel = 201 and CO512 = 511 else '0';
---enb_201 <= '1' when CW3Sel = 202 and CO512 = 511 else '0';
---enb_202 <= '1' when CW3Sel = 203 and CO512 = 511 else '0';
---enb_203 <= '1' when CW3Sel = 204 and CO512 = 511 else '0';
---enb_204 <= '1' when CW3Sel = 205 and CO512 = 511 else '0';
---enb_205 <= '1' when CW3Sel = 206 and CO512 = 511 else '0';
---enb_206 <= '1' when CW3Sel = 207 and CO512 = 511 else '0';
---enb_207 <= '1' when CW3Sel = 208 and CO512 = 511 else '0';
---enb_208 <= '1' when CW3Sel = 209 and CO512 = 511 else '0';
---enb_209 <= '1' when CW3Sel = 210 and CO512 = 511 else '0';
---enb_210 <= '1' when CW3Sel = 211 and CO512 = 511 else '0';
---enb_211 <= '1' when CW3Sel = 212 and CO512 = 511 else '0';
---enb_212 <= '1' when CW3Sel = 213 and CO512 = 511 else '0';
---enb_213 <= '1' when CW3Sel = 214 and CO512 = 511 else '0';
---enb_214 <= '1' when CW3Sel = 215 and CO512 = 511 else '0';
---enb_215 <= '1' when CW3Sel = 216 and CO512 = 511 else '0';
---enb_216 <= '1' when CW3Sel = 217 and CO512 = 511 else '0';
---enb_217 <= '1' when CW3Sel = 218 and CO512 = 511 else '0';
---enb_218 <= '1' when CW3Sel = 219 and CO512 = 511 else '0';
---enb_219 <= '1' when CW3Sel = 220 and CO512 = 511 else '0';
---enb_220 <= '1' when CW3Sel = 221 and CO512 = 511 else '0';
---enb_221 <= '1' when CW3Sel = 222 and CO512 = 511 else '0';
---enb_222 <= '1' when CW3Sel = 223 and CO512 = 511 else '0';
---enb_223 <= '1' when CW3Sel = 224 and CO512 = 511 else '0';
---enb_224 <= '1' when CW3Sel = 225 and CO512 = 511 else '0';
---enb_225 <= '1' when CW3Sel = 226 and CO512 = 511 else '0';
---enb_226 <= '1' when CW3Sel = 227 and CO512 = 511 else '0';
---enb_227 <= '1' when CW3Sel = 228 and CO512 = 511 else '0';
---enb_228 <= '1' when CW3Sel = 229 and CO512 = 511 else '0';
---enb_229 <= '1' when CW3Sel = 230 and CO512 = 511 else '0';
---enb_230 <= '1' when CW3Sel = 231 and CO512 = 511 else '0';
---enb_231 <= '1' when CW3Sel = 232 and CO512 = 511 else '0';
---enb_232 <= '1' when CW3Sel = 233 and CO512 = 511 else '0';
---enb_233 <= '1' when CW3Sel = 234 and CO512 = 511 else '0';
---enb_234 <= '1' when CW3Sel = 235 and CO512 = 511 else '0';
---enb_235 <= '1' when CW3Sel = 236 and CO512 = 511 else '0';
---enb_236 <= '1' when CW3Sel = 237 and CO512 = 511 else '0';
---enb_237 <= '1' when CW3Sel = 238 and CO512 = 511 else '0';
---enb_238 <= '1' when CW3Sel = 239 and CO512 = 511 else '0';
---enb_239 <= '1' when CW3Sel = 240 and CO512 = 511 else '0';
---enb_240 <= '1' when CW3Sel = 241 and CO512 = 511 else '0';
---enb_241 <= '1' when CW3Sel = 242 and CO512 = 511 else '0';
---enb_242 <= '1' when CW3Sel = 243 and CO512 = 511 else '0';
---enb_243 <= '1' when CW3Sel = 244 and CO512 = 511 else '0';
---enb_244 <= '1' when CW3Sel = 245 and CO512 = 511 else '0';
---enb_245 <= '1' when CW3Sel = 246 and CO512 = 511 else '0';
---enb_246 <= '1' when CW3Sel = 247 and CO512 = 511 else '0';
---enb_247 <= '1' when CW3Sel = 248 and CO512 = 511 else '0';
---enb_248 <= '1' when CW3Sel = 249 and CO512 = 511 else '0';
---enb_249 <= '1' when CW3Sel = 250 and CO512 = 511 else '0';
---enb_250 <= '1' when CW3Sel = 251 and CO512 = 511 else '0';
---enb_251 <= '1' when CW3Sel = 252 and CO512 = 511 else '0';
---enb_252 <= '1' when CW3Sel = 253 and CO512 = 511 else '0';
---enb_253 <= '1' when CW3Sel = 254 and CO512 = 511 else '0';
---enb_254 <= '1' when CW3Sel = 255 and CO512 = 511 else '0';
---enb_255 <= '1' when CW3Sel = 0 and CO512 = 511 else '0';

-----------------------------------------------------------
process( RST_N, CLK )  
begin 
  if( CLK'event and CLK = '1' ) then
    if(enb_000 = '1') then reg_000_000 <= Relu_000;
    elsif(enb_001 = '1') then reg_000_001 <= Relu_000;
    elsif(enb_002 = '1') then reg_000_002 <= Relu_000;
    elsif(enb_003 = '1') then reg_000_003 <= Relu_000;
    elsif(enb_004 = '1') then reg_000_004 <= Relu_000;
    elsif(enb_005 = '1') then reg_000_005 <= Relu_000;
    elsif(enb_006 = '1') then reg_000_006 <= Relu_000;
    elsif(enb_007 = '1') then reg_000_007 <= Relu_000;
    elsif(enb_008 = '1') then reg_000_008 <= Relu_000;
    elsif(enb_009 = '1') then reg_000_009 <= Relu_000;
    elsif(enb_010 = '1') then reg_000_010 <= Relu_000;
    elsif(enb_011 = '1') then reg_000_011 <= Relu_000;
    elsif(enb_012 = '1') then reg_000_012 <= Relu_000;
    elsif(enb_013 = '1') then reg_000_013 <= Relu_000;
    elsif(enb_014 = '1') then reg_000_014 <= Relu_000;
    elsif(enb_015 = '1') then reg_000_015 <= Relu_000;
    elsif(enb_016 = '1') then reg_000_016 <= Relu_000;
    elsif(enb_017 = '1') then reg_000_017 <= Relu_000;
    elsif(enb_018 = '1') then reg_000_018 <= Relu_000;
    elsif(enb_019 = '1') then reg_000_019 <= Relu_000;
    elsif(enb_020 = '1') then reg_000_020 <= Relu_000;
    elsif(enb_021 = '1') then reg_000_021 <= Relu_000;
    elsif(enb_022 = '1') then reg_000_022 <= Relu_000;
    elsif(enb_023 = '1') then reg_000_023 <= Relu_000;
    elsif(enb_024 = '1') then reg_000_024 <= Relu_000;
    elsif(enb_025 = '1') then reg_000_025 <= Relu_000;
    elsif(enb_026 = '1') then reg_000_026 <= Relu_000;
    elsif(enb_027 = '1') then reg_000_027 <= Relu_000;
    elsif(enb_028 = '1') then reg_000_028 <= Relu_000;
    elsif(enb_029 = '1') then reg_000_029 <= Relu_000;
    elsif(enb_030 = '1') then reg_000_030 <= Relu_000;
    elsif(enb_031 = '1') then reg_000_031 <= Relu_000;
    elsif(enb_032 = '1') then reg_000_032 <= Relu_000;
    elsif(enb_033 = '1') then reg_000_033 <= Relu_000;
    elsif(enb_034 = '1') then reg_000_034 <= Relu_000;
    elsif(enb_035 = '1') then reg_000_035 <= Relu_000;
    elsif(enb_036 = '1') then reg_000_036 <= Relu_000;
    elsif(enb_037 = '1') then reg_000_037 <= Relu_000;
    elsif(enb_038 = '1') then reg_000_038 <= Relu_000;
    elsif(enb_039 = '1') then reg_000_039 <= Relu_000;
    elsif(enb_040 = '1') then reg_000_040 <= Relu_000;
    elsif(enb_041 = '1') then reg_000_041 <= Relu_000;
    elsif(enb_042 = '1') then reg_000_042 <= Relu_000;
    elsif(enb_043 = '1') then reg_000_043 <= Relu_000;
    elsif(enb_044 = '1') then reg_000_044 <= Relu_000;
    elsif(enb_045 = '1') then reg_000_045 <= Relu_000;
    elsif(enb_046 = '1') then reg_000_046 <= Relu_000;
    elsif(enb_047 = '1') then reg_000_047 <= Relu_000;
    elsif(enb_048 = '1') then reg_000_048 <= Relu_000;
    elsif(enb_049 = '1') then reg_000_049 <= Relu_000;
    elsif(enb_050 = '1') then reg_000_050 <= Relu_000;
    elsif(enb_051 = '1') then reg_000_051 <= Relu_000;
    elsif(enb_052 = '1') then reg_000_052 <= Relu_000;
    elsif(enb_053 = '1') then reg_000_053 <= Relu_000;
    elsif(enb_054 = '1') then reg_000_054 <= Relu_000;
    elsif(enb_055 = '1') then reg_000_055 <= Relu_000;
    elsif(enb_056 = '1') then reg_000_056 <= Relu_000;
    elsif(enb_057 = '1') then reg_000_057 <= Relu_000;
    elsif(enb_058 = '1') then reg_000_058 <= Relu_000;
    elsif(enb_059 = '1') then reg_000_059 <= Relu_000;
    elsif(enb_060 = '1') then reg_000_060 <= Relu_000;
    elsif(enb_061 = '1') then reg_000_061 <= Relu_000;
    elsif(enb_062 = '1') then reg_000_062 <= Relu_000;
    elsif(enb_063 = '1') then reg_000_063 <= Relu_000;
    end if;
  end if;  
end process;


process( RST_N, CLK )  
begin 
  if( CLK'event and CLK = '1' ) then
    if(enb_000 = '1') then reg_001_000 <= Relu_001;
    elsif(enb_001 = '1') then reg_001_001 <= Relu_001;
    elsif(enb_002 = '1') then reg_001_002 <= Relu_001;
    elsif(enb_003 = '1') then reg_001_003 <= Relu_001;
    elsif(enb_004 = '1') then reg_001_004 <= Relu_001;
    elsif(enb_005 = '1') then reg_001_005 <= Relu_001;
    elsif(enb_006 = '1') then reg_001_006 <= Relu_001;
    elsif(enb_007 = '1') then reg_001_007 <= Relu_001;
    elsif(enb_008 = '1') then reg_001_008 <= Relu_001;
    elsif(enb_009 = '1') then reg_001_009 <= Relu_001;
    elsif(enb_010 = '1') then reg_001_010 <= Relu_001;
    elsif(enb_011 = '1') then reg_001_011 <= Relu_001;
    elsif(enb_012 = '1') then reg_001_012 <= Relu_001;
    elsif(enb_013 = '1') then reg_001_013 <= Relu_001;
    elsif(enb_014 = '1') then reg_001_014 <= Relu_001;
    elsif(enb_015 = '1') then reg_001_015 <= Relu_001;
    elsif(enb_016 = '1') then reg_001_016 <= Relu_001;
    elsif(enb_017 = '1') then reg_001_017 <= Relu_001;
    elsif(enb_018 = '1') then reg_001_018 <= Relu_001;
    elsif(enb_019 = '1') then reg_001_019 <= Relu_001;
    elsif(enb_020 = '1') then reg_001_020 <= Relu_001;
    elsif(enb_021 = '1') then reg_001_021 <= Relu_001;
    elsif(enb_022 = '1') then reg_001_022 <= Relu_001;
    elsif(enb_023 = '1') then reg_001_023 <= Relu_001;
    elsif(enb_024 = '1') then reg_001_024 <= Relu_001;
    elsif(enb_025 = '1') then reg_001_025 <= Relu_001;
    elsif(enb_026 = '1') then reg_001_026 <= Relu_001;
    elsif(enb_027 = '1') then reg_001_027 <= Relu_001;
    elsif(enb_028 = '1') then reg_001_028 <= Relu_001;
    elsif(enb_029 = '1') then reg_001_029 <= Relu_001;
    elsif(enb_030 = '1') then reg_001_030 <= Relu_001;
    elsif(enb_031 = '1') then reg_001_031 <= Relu_001;
    elsif(enb_032 = '1') then reg_001_032 <= Relu_001;
    elsif(enb_033 = '1') then reg_001_033 <= Relu_001;
    elsif(enb_034 = '1') then reg_001_034 <= Relu_001;
    elsif(enb_035 = '1') then reg_001_035 <= Relu_001;
    elsif(enb_036 = '1') then reg_001_036 <= Relu_001;
    elsif(enb_037 = '1') then reg_001_037 <= Relu_001;
    elsif(enb_038 = '1') then reg_001_038 <= Relu_001;
    elsif(enb_039 = '1') then reg_001_039 <= Relu_001;
    elsif(enb_040 = '1') then reg_001_040 <= Relu_001;
    elsif(enb_041 = '1') then reg_001_041 <= Relu_001;
    elsif(enb_042 = '1') then reg_001_042 <= Relu_001;
    elsif(enb_043 = '1') then reg_001_043 <= Relu_001;
    elsif(enb_044 = '1') then reg_001_044 <= Relu_001;
    elsif(enb_045 = '1') then reg_001_045 <= Relu_001;
    elsif(enb_046 = '1') then reg_001_046 <= Relu_001;
    elsif(enb_047 = '1') then reg_001_047 <= Relu_001;
    elsif(enb_048 = '1') then reg_001_048 <= Relu_001;
    elsif(enb_049 = '1') then reg_001_049 <= Relu_001;
    elsif(enb_050 = '1') then reg_001_050 <= Relu_001;
    elsif(enb_051 = '1') then reg_001_051 <= Relu_001;
    elsif(enb_052 = '1') then reg_001_052 <= Relu_001;
    elsif(enb_053 = '1') then reg_001_053 <= Relu_001;
    elsif(enb_054 = '1') then reg_001_054 <= Relu_001;
    elsif(enb_055 = '1') then reg_001_055 <= Relu_001;
    elsif(enb_056 = '1') then reg_001_056 <= Relu_001;
    elsif(enb_057 = '1') then reg_001_057 <= Relu_001;
    elsif(enb_058 = '1') then reg_001_058 <= Relu_001;
    elsif(enb_059 = '1') then reg_001_059 <= Relu_001;
    elsif(enb_060 = '1') then reg_001_060 <= Relu_001;
    elsif(enb_061 = '1') then reg_001_061 <= Relu_001;
    elsif(enb_062 = '1') then reg_001_062 <= Relu_001;
    elsif(enb_063 = '1') then reg_001_063 <= Relu_001;
    end if;
  end if;  
end process;


---    elsif(enb_064 = '1') then reg_000_064 <= Relu_000;
---    elsif(enb_065 = '1') then reg_000_065 <= Relu_000;
---    elsif(enb_066 = '1') then reg_000_066 <= Relu_000;
---    elsif(enb_067 = '1') then reg_000_067 <= Relu_000;
---    elsif(enb_068 = '1') then reg_000_068 <= Relu_000;
---    elsif(enb_069 = '1') then reg_000_069 <= Relu_000;
---    elsif(enb_070 = '1') then reg_000_070 <= Relu_000;
---    elsif(enb_071 = '1') then reg_000_071 <= Relu_000;
---    elsif(enb_072 = '1') then reg_000_072 <= Relu_000;
---    elsif(enb_073 = '1') then reg_000_073 <= Relu_000;
---    elsif(enb_074 = '1') then reg_000_074 <= Relu_000;
---    elsif(enb_075 = '1') then reg_000_075 <= Relu_000;
---    elsif(enb_076 = '1') then reg_000_076 <= Relu_000;
---    elsif(enb_077 = '1') then reg_000_077 <= Relu_000;
---    elsif(enb_078 = '1') then reg_000_078 <= Relu_000;
---    elsif(enb_079 = '1') then reg_000_079 <= Relu_000;
---    elsif(enb_080 = '1') then reg_000_080 <= Relu_000;
---    elsif(enb_081 = '1') then reg_000_081 <= Relu_000;
---    elsif(enb_082 = '1') then reg_000_082 <= Relu_000;
---    elsif(enb_083 = '1') then reg_000_083 <= Relu_000;
---    elsif(enb_084 = '1') then reg_000_084 <= Relu_000;
---    elsif(enb_085 = '1') then reg_000_085 <= Relu_000;
---    elsif(enb_086 = '1') then reg_000_086 <= Relu_000;
---    elsif(enb_087 = '1') then reg_000_087 <= Relu_000;
---    elsif(enb_088 = '1') then reg_000_088 <= Relu_000;
---    elsif(enb_089 = '1') then reg_000_089 <= Relu_000;
---    elsif(enb_090 = '1') then reg_000_090 <= Relu_000;
---    elsif(enb_091 = '1') then reg_000_091 <= Relu_000;
---    elsif(enb_092 = '1') then reg_000_092 <= Relu_000;
---    elsif(enb_093 = '1') then reg_000_093 <= Relu_000;
---    elsif(enb_094 = '1') then reg_000_094 <= Relu_000;
---    elsif(enb_095 = '1') then reg_000_095 <= Relu_000;
---    elsif(enb_096 = '1') then reg_000_096 <= Relu_000;
---    elsif(enb_097 = '1') then reg_000_097 <= Relu_000;
---    elsif(enb_098 = '1') then reg_000_098 <= Relu_000;
---    elsif(enb_099 = '1') then reg_000_099 <= Relu_000;
---    elsif(enb_100 = '1') then reg_000_100 <= Relu_000;
---    elsif(enb_101 = '1') then reg_000_101 <= Relu_000;
---    elsif(enb_102 = '1') then reg_000_102 <= Relu_000;
---    elsif(enb_103 = '1') then reg_000_103 <= Relu_000;
---    elsif(enb_104 = '1') then reg_000_104 <= Relu_000;
---    elsif(enb_105 = '1') then reg_000_105 <= Relu_000;
---    elsif(enb_106 = '1') then reg_000_106 <= Relu_000;
---    elsif(enb_107 = '1') then reg_000_107 <= Relu_000;
---    elsif(enb_108 = '1') then reg_000_108 <= Relu_000;
---    elsif(enb_109 = '1') then reg_000_109 <= Relu_000;
---    elsif(enb_110 = '1') then reg_000_110 <= Relu_000;
---    elsif(enb_111 = '1') then reg_000_111 <= Relu_000;
---    elsif(enb_112 = '1') then reg_000_112 <= Relu_000;
---    elsif(enb_113 = '1') then reg_000_113 <= Relu_000;
---    elsif(enb_114 = '1') then reg_000_114 <= Relu_000;
---    elsif(enb_115 = '1') then reg_000_115 <= Relu_000;
---    elsif(enb_116 = '1') then reg_000_116 <= Relu_000;
---    elsif(enb_117 = '1') then reg_000_117 <= Relu_000;
---    elsif(enb_118 = '1') then reg_000_118 <= Relu_000;
---    elsif(enb_119 = '1') then reg_000_119 <= Relu_000;
---    elsif(enb_120 = '1') then reg_000_120 <= Relu_000;
---    elsif(enb_121 = '1') then reg_000_121 <= Relu_000;
---    elsif(enb_122 = '1') then reg_000_122 <= Relu_000;
---    elsif(enb_123 = '1') then reg_000_123 <= Relu_000;
---    elsif(enb_124 = '1') then reg_000_124 <= Relu_000;
---    elsif(enb_125 = '1') then reg_000_125 <= Relu_000;
---    elsif(enb_126 = '1') then reg_000_126 <= Relu_000;
---    elsif(enb_127 = '1') then reg_000_127 <= Relu_000;
---    elsif(enb_128 = '1') then reg_000_128 <= Relu_000;
---    elsif(enb_129 = '1') then reg_000_129 <= Relu_000;
---    elsif(enb_130 = '1') then reg_000_130 <= Relu_000;
---    elsif(enb_131 = '1') then reg_000_131 <= Relu_000;
---    elsif(enb_132 = '1') then reg_000_132 <= Relu_000;
---    elsif(enb_133 = '1') then reg_000_133 <= Relu_000;
---    elsif(enb_134 = '1') then reg_000_134 <= Relu_000;
---    elsif(enb_135 = '1') then reg_000_135 <= Relu_000;
---    elsif(enb_136 = '1') then reg_000_136 <= Relu_000;
---    elsif(enb_137 = '1') then reg_000_137 <= Relu_000;
---    elsif(enb_138 = '1') then reg_000_138 <= Relu_000;
---    elsif(enb_139 = '1') then reg_000_139 <= Relu_000;
---    elsif(enb_140 = '1') then reg_000_140 <= Relu_000;
---    elsif(enb_141 = '1') then reg_000_141 <= Relu_000;
---    elsif(enb_142 = '1') then reg_000_142 <= Relu_000;
---    elsif(enb_143 = '1') then reg_000_143 <= Relu_000;
---    elsif(enb_144 = '1') then reg_000_144 <= Relu_000;
---    elsif(enb_145 = '1') then reg_000_145 <= Relu_000;
---    elsif(enb_146 = '1') then reg_000_146 <= Relu_000;
---    elsif(enb_147 = '1') then reg_000_147 <= Relu_000;
---    elsif(enb_148 = '1') then reg_000_148 <= Relu_000;
---    elsif(enb_149 = '1') then reg_000_149 <= Relu_000;
---    elsif(enb_150 = '1') then reg_000_150 <= Relu_000;
---    elsif(enb_151 = '1') then reg_000_151 <= Relu_000;
---    elsif(enb_152 = '1') then reg_000_152 <= Relu_000;
---    elsif(enb_153 = '1') then reg_000_153 <= Relu_000;
---    elsif(enb_154 = '1') then reg_000_154 <= Relu_000;
---    elsif(enb_155 = '1') then reg_000_155 <= Relu_000;
---    elsif(enb_156 = '1') then reg_000_156 <= Relu_000;
---    elsif(enb_157 = '1') then reg_000_157 <= Relu_000;
---    elsif(enb_158 = '1') then reg_000_158 <= Relu_000;
---    elsif(enb_159 = '1') then reg_000_159 <= Relu_000;
---    elsif(enb_160 = '1') then reg_000_160 <= Relu_000;
---    elsif(enb_161 = '1') then reg_000_161 <= Relu_000;
---    elsif(enb_162 = '1') then reg_000_162 <= Relu_000;
---    elsif(enb_163 = '1') then reg_000_163 <= Relu_000;
---    elsif(enb_164 = '1') then reg_000_164 <= Relu_000;
---    elsif(enb_165 = '1') then reg_000_165 <= Relu_000;
---    elsif(enb_166 = '1') then reg_000_166 <= Relu_000;
---    elsif(enb_167 = '1') then reg_000_167 <= Relu_000;
---    elsif(enb_168 = '1') then reg_000_168 <= Relu_000;
---    elsif(enb_169 = '1') then reg_000_169 <= Relu_000;
---    elsif(enb_170 = '1') then reg_000_170 <= Relu_000;
---    elsif(enb_171 = '1') then reg_000_171 <= Relu_000;
---    elsif(enb_172 = '1') then reg_000_172 <= Relu_000;
---    elsif(enb_173 = '1') then reg_000_173 <= Relu_000;
---    elsif(enb_174 = '1') then reg_000_174 <= Relu_000;
---    elsif(enb_175 = '1') then reg_000_175 <= Relu_000;
---    elsif(enb_176 = '1') then reg_000_176 <= Relu_000;
---    elsif(enb_177 = '1') then reg_000_177 <= Relu_000;
---    elsif(enb_178 = '1') then reg_000_178 <= Relu_000;
---    elsif(enb_179 = '1') then reg_000_179 <= Relu_000;
---    elsif(enb_180 = '1') then reg_000_180 <= Relu_000;
---    elsif(enb_181 = '1') then reg_000_181 <= Relu_000;
---    elsif(enb_182 = '1') then reg_000_182 <= Relu_000;
---    elsif(enb_183 = '1') then reg_000_183 <= Relu_000;
---    elsif(enb_184 = '1') then reg_000_184 <= Relu_000;
---    elsif(enb_185 = '1') then reg_000_185 <= Relu_000;
---    elsif(enb_186 = '1') then reg_000_186 <= Relu_000;
---    elsif(enb_187 = '1') then reg_000_187 <= Relu_000;
---    elsif(enb_188 = '1') then reg_000_188 <= Relu_000;
---    elsif(enb_189 = '1') then reg_000_189 <= Relu_000;
---    elsif(enb_190 = '1') then reg_000_190 <= Relu_000;
---    elsif(enb_191 = '1') then reg_000_191 <= Relu_000;
---    elsif(enb_192 = '1') then reg_000_192 <= Relu_000;
---    elsif(enb_193 = '1') then reg_000_193 <= Relu_000;
---    elsif(enb_194 = '1') then reg_000_194 <= Relu_000;
---    elsif(enb_195 = '1') then reg_000_195 <= Relu_000;
---    elsif(enb_196 = '1') then reg_000_196 <= Relu_000;
---    elsif(enb_197 = '1') then reg_000_197 <= Relu_000;
---    elsif(enb_198 = '1') then reg_000_198 <= Relu_000;
---    elsif(enb_199 = '1') then reg_000_199 <= Relu_000;
---    elsif(enb_200 = '1') then reg_000_200 <= Relu_000;
---    elsif(enb_201 = '1') then reg_000_201 <= Relu_000;
---    elsif(enb_202 = '1') then reg_000_202 <= Relu_000;
---    elsif(enb_203 = '1') then reg_000_203 <= Relu_000;
---    elsif(enb_204 = '1') then reg_000_204 <= Relu_000;
---    elsif(enb_205 = '1') then reg_000_205 <= Relu_000;
---    elsif(enb_206 = '1') then reg_000_206 <= Relu_000;
---    elsif(enb_207 = '1') then reg_000_207 <= Relu_000;
---    elsif(enb_208 = '1') then reg_000_208 <= Relu_000;
---    elsif(enb_209 = '1') then reg_000_209 <= Relu_000;
---    elsif(enb_210 = '1') then reg_000_210 <= Relu_000;
---    elsif(enb_211 = '1') then reg_000_211 <= Relu_000;
---    elsif(enb_212 = '1') then reg_000_212 <= Relu_000;
---    elsif(enb_213 = '1') then reg_000_213 <= Relu_000;
---    elsif(enb_214 = '1') then reg_000_214 <= Relu_000;
---    elsif(enb_215 = '1') then reg_000_215 <= Relu_000;
---    elsif(enb_216 = '1') then reg_000_216 <= Relu_000;
---    elsif(enb_217 = '1') then reg_000_217 <= Relu_000;
---    elsif(enb_218 = '1') then reg_000_218 <= Relu_000;
---    elsif(enb_219 = '1') then reg_000_219 <= Relu_000;
---    elsif(enb_220 = '1') then reg_000_220 <= Relu_000;
---    elsif(enb_221 = '1') then reg_000_221 <= Relu_000;
---    elsif(enb_222 = '1') then reg_000_222 <= Relu_000;
---    elsif(enb_223 = '1') then reg_000_223 <= Relu_000;
---    elsif(enb_224 = '1') then reg_000_224 <= Relu_000;
---    elsif(enb_225 = '1') then reg_000_225 <= Relu_000;
---    elsif(enb_226 = '1') then reg_000_226 <= Relu_000;
---    elsif(enb_227 = '1') then reg_000_227 <= Relu_000;
---    elsif(enb_228 = '1') then reg_000_228 <= Relu_000;
---    elsif(enb_229 = '1') then reg_000_229 <= Relu_000;
---    elsif(enb_230 = '1') then reg_000_230 <= Relu_000;
---    elsif(enb_231 = '1') then reg_000_231 <= Relu_000;
---    elsif(enb_232 = '1') then reg_000_232 <= Relu_000;
---    elsif(enb_233 = '1') then reg_000_233 <= Relu_000;
---    elsif(enb_234 = '1') then reg_000_234 <= Relu_000;
---    elsif(enb_235 = '1') then reg_000_235 <= Relu_000;
---    elsif(enb_236 = '1') then reg_000_236 <= Relu_000;
---    elsif(enb_237 = '1') then reg_000_237 <= Relu_000;
---    elsif(enb_238 = '1') then reg_000_238 <= Relu_000;
---    elsif(enb_239 = '1') then reg_000_239 <= Relu_000;
---    elsif(enb_240 = '1') then reg_000_240 <= Relu_000;
---    elsif(enb_241 = '1') then reg_000_241 <= Relu_000;
---    elsif(enb_242 = '1') then reg_000_242 <= Relu_000;
---    elsif(enb_243 = '1') then reg_000_243 <= Relu_000;
---    elsif(enb_244 = '1') then reg_000_244 <= Relu_000;
---    elsif(enb_245 = '1') then reg_000_245 <= Relu_000;
---    elsif(enb_246 = '1') then reg_000_246 <= Relu_000;
---    elsif(enb_247 = '1') then reg_000_247 <= Relu_000;
---    elsif(enb_248 = '1') then reg_000_248 <= Relu_000;
---    elsif(enb_249 = '1') then reg_000_249 <= Relu_000;
---    elsif(enb_250 = '1') then reg_000_250 <= Relu_000;
---    elsif(enb_251 = '1') then reg_000_251 <= Relu_000;
---    elsif(enb_252 = '1') then reg_000_252 <= Relu_000;
---    elsif(enb_253 = '1') then reg_000_253 <= Relu_000;
---    elsif(enb_254 = '1') then reg_000_254 <= Relu_000;
---    elsif(enb_255 = '1') then reg_000_255 <= Relu_000;

-------------------------------------------------------
ROM_CW3_inst : ROM_CW3 port map (
  CLK => CLK,
  ADDR => CW3Addr,
  DATA => CW3Data );

---------------------------------------------------------
coeff_000 <= 
CW3Data( 377 downto 375 ) when CW3Sel = "00000000" else 
CW3Data( 374 downto 372 ) when CW3Sel = "00000001" else 
CW3Data( 371 downto 369 ) when CW3Sel = "00000010" else 
CW3Data( 368 downto 366 ) when CW3Sel = "00000011" else 
CW3Data( 365 downto 363 ) when CW3Sel = "00000100" else 
CW3Data( 362 downto 360 ) when CW3Sel = "00000101" else 
CW3Data( 359 downto 357 ) when CW3Sel = "00000110" else 
CW3Data( 356 downto 354 ) when CW3Sel = "00000111" else 
CW3Data( 353 downto 351 ) when CW3Sel = "00001000" else 
CW3Data( 350 downto 348 ) when CW3Sel = "00001001" else 
CW3Data( 347 downto 345 ) when CW3Sel = "00001010" else 
CW3Data( 344 downto 342 ) when CW3Sel = "00001011" else 
CW3Data( 341 downto 339 ) when CW3Sel = "00001100" else 
CW3Data( 338 downto 336 ) when CW3Sel = "00001101" else 
CW3Data( 335 downto 333 ) when CW3Sel = "00001110" else 
CW3Data( 332 downto 330 ) when CW3Sel = "00001111" else 
CW3Data( 329 downto 327 ) when CW3Sel = "00010000" else 
CW3Data( 326 downto 324 ) when CW3Sel = "00010001" else 
CW3Data( 323 downto 321 ) when CW3Sel = "00010010" else 
CW3Data( 320 downto 318 ) when CW3Sel = "00010011" else 
CW3Data( 317 downto 315 ) when CW3Sel = "00010100" else 
CW3Data( 314 downto 312 ) when CW3Sel = "00010101" else 
CW3Data( 311 downto 309 ) when CW3Sel = "00010110" else 
CW3Data( 308 downto 306 ) when CW3Sel = "00010111" else 
CW3Data( 305 downto 303 ) when CW3Sel = "00011000" else 
CW3Data( 302 downto 300 ) when CW3Sel = "00011001" else 
CW3Data( 299 downto 297 ) when CW3Sel = "00011010" else 
CW3Data( 296 downto 294 ) when CW3Sel = "00011011" else 
CW3Data( 293 downto 291 ) when CW3Sel = "00011100" else 
CW3Data( 290 downto 288 ) when CW3Sel = "00011101" else 
CW3Data( 287 downto 285 ) when CW3Sel = "00011110" else 
CW3Data( 284 downto 282 ) when CW3Sel = "00011111" else 
CW3Data( 281 downto 279 ) when CW3Sel = "00100000" else 
CW3Data( 278 downto 276 ) when CW3Sel = "00100001" else 
CW3Data( 275 downto 273 ) when CW3Sel = "00100010" else 
CW3Data( 272 downto 270 ) when CW3Sel = "00100011" else 
CW3Data( 269 downto 267 ) when CW3Sel = "00100100" else 
CW3Data( 266 downto 264 ) when CW3Sel = "00100101" else 
CW3Data( 263 downto 261 ) when CW3Sel = "00100110" else 
CW3Data( 260 downto 258 ) when CW3Sel = "00100111" else 
CW3Data( 257 downto 255 ) when CW3Sel = "00101000" else 
CW3Data( 254 downto 252 ) when CW3Sel = "00101001" else 
CW3Data( 251 downto 249 ) when CW3Sel = "00101010" else 
CW3Data( 248 downto 246 ) when CW3Sel = "00101011" else 
CW3Data( 245 downto 243 ) when CW3Sel = "00101100" else 
CW3Data( 242 downto 240 ) when CW3Sel = "00101101" else 
CW3Data( 239 downto 237 ) when CW3Sel = "00101110" else 
CW3Data( 236 downto 234 ) when CW3Sel = "00101111" else 
CW3Data( 233 downto 231 ) when CW3Sel = "00110000" else 
CW3Data( 230 downto 228 ) when CW3Sel = "00110001" else 
CW3Data( 227 downto 225 ) when CW3Sel = "00110010" else 
CW3Data( 224 downto 222 ) when CW3Sel = "00110011" else 
CW3Data( 221 downto 219 ) when CW3Sel = "00110100" else 
CW3Data( 218 downto 216 ) when CW3Sel = "00110101" else 
CW3Data( 215 downto 213 ) when CW3Sel = "00110110" else 
CW3Data( 212 downto 210 ) when CW3Sel = "00110111" else 
CW3Data( 209 downto 207 ) when CW3Sel = "00111000" else 
CW3Data( 206 downto 204 ) when CW3Sel = "00111001" else 
CW3Data( 203 downto 201 ) when CW3Sel = "00111010" else 
CW3Data( 200 downto 198 ) when CW3Sel = "00111011" else 
CW3Data( 197 downto 195 ) when CW3Sel = "00111100" else 
CW3Data( 194 downto 192 ) when CW3Sel = "00111101" else 
CW3Data( 191 downto 189 ) when CW3Sel = "00111110" else 
CW3Data( 188 downto 186 ) when CW3Sel = "00111111";----else 

coeff_001 <=
CW3Data( 185 downto 183 ) when CW3Sel = "00000000" else 
CW3Data( 182 downto 180 ) when CW3Sel = "00000001" else 
CW3Data( 179 downto 177 ) when CW3Sel = "00000010" else 
CW3Data( 176 downto 174 ) when CW3Sel = "00000011" else 
CW3Data( 173 downto 171 ) when CW3Sel = "00000100" else 
CW3Data( 170 downto 168 ) when CW3Sel = "00000101" else 
CW3Data( 167 downto 165 ) when CW3Sel = "00000110" else 
CW3Data( 164 downto 162 ) when CW3Sel = "00000111" else 
CW3Data( 161 downto 159 ) when CW3Sel = "00001000" else 
CW3Data( 158 downto 156 ) when CW3Sel = "00001001" else 
CW3Data( 155 downto 153 ) when CW3Sel = "00001010" else 
CW3Data( 152 downto 150 ) when CW3Sel = "00001011" else 
CW3Data( 149 downto 147 ) when CW3Sel = "00001100" else 
CW3Data( 146 downto 144 ) when CW3Sel = "00001101" else 
CW3Data( 143 downto 141 ) when CW3Sel = "00001110" else 
CW3Data( 140 downto 138 ) when CW3Sel = "00001111" else 
CW3Data( 137 downto 135 ) when CW3Sel = "00010000" else 
CW3Data( 134 downto 132 ) when CW3Sel = "00010001" else 
CW3Data( 131 downto 129 ) when CW3Sel = "00010010" else 
CW3Data( 128 downto 126 ) when CW3Sel = "00010011" else 
CW3Data( 125 downto 123 ) when CW3Sel = "00010100" else 
CW3Data( 122 downto 120 ) when CW3Sel = "00010101" else 
CW3Data( 119 downto 117 ) when CW3Sel = "00010110" else 
CW3Data( 116 downto 114 ) when CW3Sel = "00010111" else 
CW3Data( 113 downto 111 ) when CW3Sel = "00011000" else 
CW3Data( 110 downto 108 ) when CW3Sel = "00011001" else 
CW3Data( 107 downto 105 ) when CW3Sel = "00011010" else 
CW3Data( 104 downto 102 ) when CW3Sel = "00011011" else 
CW3Data( 101 downto 99 ) when CW3Sel = "00011100" else 
CW3Data( 98 downto 96 ) when CW3Sel = "00011101" else 
CW3Data( 95 downto 93 ) when CW3Sel = "00011110" else 
CW3Data( 92 downto 90 ) when CW3Sel = "00011111" else 
CW3Data( 89 downto 87 ) when CW3Sel = "00100000" else 
CW3Data( 86 downto 84 ) when CW3Sel = "00100001" else 
CW3Data( 83 downto 81 ) when CW3Sel = "00100010" else 
CW3Data( 80 downto 78 ) when CW3Sel = "00100011" else 
CW3Data( 77 downto 75 ) when CW3Sel = "00100100" else 
CW3Data( 74 downto 72 ) when CW3Sel = "00100101" else 
CW3Data( 71 downto 69 ) when CW3Sel = "00100110" else 
CW3Data( 68 downto 66 ) when CW3Sel = "00100111" else 
CW3Data( 65 downto 63 ) when CW3Sel = "00101000" else 
CW3Data( 62 downto 60 ) when CW3Sel = "00101001" else 
CW3Data( 59 downto 57 ) when CW3Sel = "00101010" else 
CW3Data( 56 downto 54 ) when CW3Sel = "00101011" else 
CW3Data( 53 downto 51 ) when CW3Sel = "00101100" else 
CW3Data( 50 downto 48 ) when CW3Sel = "00101101" else 
CW3Data( 47 downto 45 ) when CW3Sel = "00101110" else 
CW3Data( 44 downto 42 ) when CW3Sel = "00101111" else 
CW3Data( 41 downto 39 ) when CW3Sel = "00110000" else 
CW3Data( 38 downto 36 ) when CW3Sel = "00110001" else 
CW3Data( 35 downto 33 ) when CW3Sel = "00110010" else 
CW3Data( 32 downto 30 ) when CW3Sel = "00110011" else 
CW3Data( 29 downto 27 ) when CW3Sel = "00110100" else 
CW3Data( 26 downto 24 ) when CW3Sel = "00110101" else 
CW3Data( 23 downto 21 ) when CW3Sel = "00110110" else 
CW3Data( 20 downto 18 ) when CW3Sel = "00110111" else 
CW3Data( 17 downto 15 ) when CW3Sel = "00111000" else 
CW3Data( 14 downto 12 ) when CW3Sel = "00111001" else 
CW3Data( 11 downto 9 ) when CW3Sel = "00111010" else 
CW3Data( 8 downto 6 ) when CW3Sel = "00111011" else 
CW3Data( 5 downto 3 ) when CW3Sel = "00111100" else 
CW3Data( 2 downto 0 ); -- when CW3Sel = "00111101" else 


---------------------------------------------------------
dotpro_conf3_000 : dotpro_conf3 port map (
  CLK => CLK,
  RST_N => RST_N,
  PixRomData => PixRomData,
  MatRomData => coeff_000,
  CO9is1 => CO9is1,
  CO512is0 => CO512is0,
  MATMULOUT => mac_000 );

dotpro_conf3_001 : dotpro_conf3 port map (
  CLK => CLK,
  RST_N => RST_N,
  PixRomData => PixRomData,
  MatRomData => coeff_001,
  CO9is1 => CO9is1,
  CO512is0 => CO512is0,
  MATMULOUT => mac_001 );

-------------------------------------------------------
  truncate_000 <= mac_000(17 downto 4);
  truncate_001 <= mac_001(17 downto 4);

---------------------------------------------------------
  Relu_000 <= "1000000000000" when truncate_000 < -4096 else
             "0111111111111" when truncate_000 > 4095 else
             truncate_000(12 downto 0);

  Relu_001 <= "1000000000000" when truncate_001 < -4096 else
             "0111111111111" when truncate_001 > 4095 else
             truncate_001(12 downto 0);


--ReluSum <= ("0000000" & Relu_00) + ("0000000" & Relu_01)
--		+ ("0000000" & Relu_02) + ("0000000" & Relu_03)
--		+ ("0000000" & Relu_04) + ("0000000" & Relu_05)
--		+ ("0000000" & Relu_06) + ("0000000" & Relu_07)
--		+ ("0000000" & Relu_08) + ("0000000" & Relu_09)
--
--		+ ("0000000" & Relu_10) + ("0000000" & Relu_11)
--		+ ("0000000" & Relu_12) + ("0000000" & Relu_13)
--		+ ("0000000" & Relu_14) + ("0000000" & Relu_15)
--		+ ("0000000" & Relu_16) + ("0000000" & Relu_17)
--		+ ("0000000" & Relu_18) + ("0000000" & Relu_19)
--
--		+ ("0000000" & Relu_20) + ("0000000" & Relu_21)
--		+ ("0000000" & Relu_22) + ("0000000" & Relu_23)
--		+ ("0000000" & Relu_24) + ("0000000" & Relu_25)
--		+ ("0000000" & Relu_26) + ("0000000" & Relu_27)
--		+ ("0000000" & Relu_28) + ("0000000" & Relu_29)
--
--		+ ("0000000" & Relu_30) + ("0000000" & Relu_31);

ReluAll <= 
	reg_000_000 & reg_000_001 & reg_000_002 & reg_000_003 & reg_000_004 & reg_000_005 & reg_000_006 & reg_000_007 & reg_000_008 & reg_000_009 & 
	reg_000_010 & reg_000_011 & reg_000_012 & reg_000_013 & reg_000_014 & reg_000_015 & reg_000_016 & reg_000_017 & reg_000_018 & reg_000_019 & 
	reg_000_020 & reg_000_021 & reg_000_022 & reg_000_023 & reg_000_024 & reg_000_025 & reg_000_026 & reg_000_027 & reg_000_028 & reg_000_029 & 
	reg_000_030 & reg_000_031 & reg_000_032 & reg_000_033 & reg_000_034 & reg_000_035 & reg_000_036 & reg_000_037 & reg_000_038 & reg_000_039 & 
	reg_000_040 & reg_000_041 & reg_000_042 & reg_000_043 & reg_000_044 & reg_000_045 & reg_000_046 & reg_000_047 & reg_000_048 & reg_000_049 & 
	reg_000_050 & reg_000_051 & reg_000_052 & reg_000_053 & reg_000_054 & reg_000_055 & reg_000_056 & reg_000_057 & reg_000_058 & reg_000_059 & 
	reg_000_060 & reg_000_061 & reg_000_062 & reg_000_063 &

	reg_001_000 & reg_001_001 & reg_001_002 & reg_001_003 & reg_001_004 & reg_001_005 & reg_001_006 & reg_001_007 & reg_001_008 & reg_001_009 & 
	reg_001_010 & reg_001_011 & reg_001_012 & reg_001_013 & reg_001_014 & reg_001_015 & reg_001_016 & reg_001_017 & reg_001_018 & reg_001_019 & 
	reg_001_020 & reg_001_021 & reg_001_022 & reg_001_023 & reg_001_024 & reg_001_025 & reg_001_026 & reg_001_027 & reg_001_028 & reg_001_029 & 
	reg_001_030 & reg_001_031 & reg_001_032 & reg_001_033 & reg_001_034 & reg_001_035 & reg_001_036 & reg_001_037 & reg_001_038 & reg_001_039 & 
	reg_001_040 & reg_001_041 & reg_001_042 & reg_001_043 & reg_001_044 & reg_001_045 & reg_001_046 & reg_001_047 & reg_001_048 & reg_001_049 & 
	reg_001_050 & reg_001_051 & reg_001_052 & reg_001_053 & reg_001_054 & reg_001_055 & reg_001_056 & reg_001_057 & reg_001_058 & reg_001_059 & 
	reg_001_060 & reg_001_061; ---- & reg_001_062 & reg_001_063 &



---& reg_000_064 & reg_000_065 & reg_000_066 & reg_000_067 & reg_000_068 & reg_000_069 & 
---	reg_000_070 & reg_000_071 & reg_000_072 & reg_000_073 & reg_000_074 & reg_000_075 & reg_000_076 & reg_000_077 & reg_000_078 & reg_000_079 & 
---	reg_000_080 & reg_000_081 & reg_000_082 & reg_000_083 & reg_000_084 & reg_000_085 & reg_000_086 & reg_000_087 & reg_000_088 & reg_000_089 & 
---	reg_000_090 & reg_000_091 & reg_000_092 & reg_000_093 & reg_000_094 & reg_000_095 & reg_000_096 & reg_000_097 & reg_000_098 & reg_000_099 & 
---	reg_000_100 & reg_000_101 & reg_000_102 & reg_000_103 & reg_000_104 & reg_000_105 & reg_000_106 & reg_000_107 & reg_000_108 & reg_000_109 & 
---	reg_000_110 & reg_000_111 & reg_000_112 & reg_000_113 & reg_000_114 & reg_000_115 & reg_000_116 & reg_000_117 & reg_000_118 & reg_000_119 & 
---	reg_000_120 & reg_000_121 & reg_000_122 & reg_000_123 & reg_000_124 & reg_000_125 ; ---- reg_000_126 & reg_000_127 & reg_000_128 & reg_000_129 & 
--	reg_000_130 & reg_000_131 & reg_000_132 & reg_000_133 & reg_000_134 & reg_000_135 & reg_000_136 & reg_000_137 & reg_000_138 & reg_000_139 & 
--	reg_000_140 & reg_000_141 & reg_000_142 & reg_000_143 & reg_000_144 & reg_000_145 & reg_000_146 & reg_000_147 & reg_000_148 & reg_000_149 & 
--	reg_000_150 & reg_000_151 & reg_000_152 & reg_000_153 & reg_000_154 & reg_000_155 & reg_000_156 & reg_000_157 & reg_000_158 & reg_000_159 & 
--	reg_000_160 & reg_000_161 & reg_000_162 & reg_000_163 & reg_000_164 & reg_000_165 & reg_000_166 & reg_000_167 & reg_000_168 & reg_000_169 & 
--	reg_000_170 & reg_000_171 & reg_000_172 & reg_000_173 & reg_000_174 & reg_000_175 & reg_000_176 & reg_000_177 & reg_000_178 & reg_000_179 & 
--	reg_000_180 & reg_000_181 & reg_000_182 & reg_000_183 & reg_000_184 & reg_000_185 & reg_000_186 & reg_000_187 & reg_000_188 & reg_000_189 & 
--	reg_000_190 & reg_000_191 & reg_000_192 & reg_000_193 & reg_000_194 & reg_000_195 & reg_000_196 & reg_000_197 & reg_000_198 & reg_000_199 & 
--	reg_000_200 & reg_000_201 & reg_000_202 & reg_000_203 & reg_000_204 & reg_000_205 & reg_000_206 & reg_000_207 & reg_000_208 & reg_000_209 & 
--	reg_000_210 & reg_000_211 & reg_000_212 & reg_000_213 & reg_000_214 & reg_000_215 & reg_000_216 & reg_000_217 & reg_000_218 & reg_000_219 & 
--	reg_000_220 & reg_000_221 & reg_000_222 & reg_000_223 & reg_000_224 & reg_000_225 & reg_000_226 & reg_000_227 & reg_000_228 & reg_000_229 & 
--	reg_000_230 & reg_000_231 & reg_000_232 & reg_000_233 & reg_000_234 & reg_000_235 & reg_000_236 & reg_000_237 & reg_000_238 & reg_000_239 & 
--	reg_000_240 & reg_000_241 & reg_000_242 & reg_000_243 & reg_000_244 & reg_000_245 & reg_000_246 & reg_000_247 & reg_000_248 & reg_000_249 & 
--	reg_000_250 & reg_000_251 & reg_000_252 & reg_000_253 & reg_000_254 & reg_000_255 ; 


ReluAllWrN <= not enb_063; -- 2022/11/04 for ex4, to write the very first data correctly to the RAM_X2

end RTL;

